# This Python file uses the following encoding: utf-8
#############################################################################
##
## Copyright (C) 2019 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of Qt for Python.
##
## $QT_BEGIN_LICENSE:LGPL$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU Lesser General Public License Usage
## Alternatively, this file may be used under the terms of the GNU Lesser
## General Public License version 3 as published by the Free Software
## Foundation and appearing in the file LICENSE.LGPL3 included in the
## packaging of this file. Please review the following information to
## ensure the GNU Lesser General Public License version 3 requirements
## will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 2.0 or (at your option) the GNU General
## Public license version 3 or any later version approved by the KDE Free
## Qt Foundation. The licenses are as published by the Free Software
## Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-2.0.html and
## https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################

from __future__ import annotations

"""
This file contains the exact signatures for all functions in module
PySide2.QtNetwork, except for defaults which are replaced by "...".
"""

# Module PySide2.QtNetwork
import PySide2
from PySide2.support.signature import typing
from PySide2.support.signature.mapping import (
    Virtual, Missing, Invalid, Default, Instance)

class Object(object): pass

import shiboken2 as Shiboken
Shiboken.Object = Object

import PySide2.QtNetwork


class QAbstractNetworkCache(PySide2.QtCore.QObject):

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def cacheSize(self) -> int: ...
    def clear(self): ...
    def data(self, url: PySide2.QtCore.QUrl) -> PySide2.QtCore.QIODevice: ...
    def insert(self, device: PySide2.QtCore.QIODevice): ...
    def metaData(self, url: PySide2.QtCore.QUrl) -> PySide2.QtNetwork.QNetworkCacheMetaData: ...
    def prepare(self, metaData: PySide2.QtNetwork.QNetworkCacheMetaData) -> PySide2.QtCore.QIODevice: ...
    def remove(self, url: PySide2.QtCore.QUrl) -> bool: ...
    def updateMetaData(self, metaData: PySide2.QtNetwork.QNetworkCacheMetaData): ...


class QAbstractSocket(PySide2.QtCore.QIODevice):

    class BindFlag(object): ...
    DefaultForPlatform       : BindFlag = ... # 0x0
    ShareAddress             : BindFlag = ... # 0x1
    DontShareAddress         : BindFlag = ... # 0x2
    ReuseAddressHint         : BindFlag = ... # 0x4

    class BindMode(object): ...

    class NetworkLayerProtocol(object): ...
    IPv4Protocol             : NetworkLayerProtocol = ... # 0x0
    IPv6Protocol             : NetworkLayerProtocol = ... # 0x1
    AnyIPProtocol            : NetworkLayerProtocol = ... # 0x2
    UnknownNetworkLayerProtocol: NetworkLayerProtocol = ... # -0x1

    class PauseMode(object): ...
    PauseNever               : PauseMode = ... # 0x0
    PauseOnSslErrors         : PauseMode = ... # 0x1

    class PauseModes(object): ...

    class SocketError(object): ...
    ConnectionRefusedError   : SocketError = ... # 0x0
    RemoteHostClosedError    : SocketError = ... # 0x1
    HostNotFoundError        : SocketError = ... # 0x2
    SocketAccessError        : SocketError = ... # 0x3
    SocketResourceError      : SocketError = ... # 0x4
    SocketTimeoutError       : SocketError = ... # 0x5
    DatagramTooLargeError    : SocketError = ... # 0x6
    NetworkError             : SocketError = ... # 0x7
    AddressInUseError        : SocketError = ... # 0x8
    SocketAddressNotAvailableError: SocketError = ... # 0x9
    UnsupportedSocketOperationError: SocketError = ... # 0xa
    UnfinishedSocketOperationError: SocketError = ... # 0xb
    ProxyAuthenticationRequiredError: SocketError = ... # 0xc
    SslHandshakeFailedError  : SocketError = ... # 0xd
    ProxyConnectionRefusedError: SocketError = ... # 0xe
    ProxyConnectionClosedError: SocketError = ... # 0xf
    ProxyConnectionTimeoutError: SocketError = ... # 0x10
    ProxyNotFoundError       : SocketError = ... # 0x11
    ProxyProtocolError       : SocketError = ... # 0x12
    OperationError           : SocketError = ... # 0x13
    SslInternalError         : SocketError = ... # 0x14
    SslInvalidUserDataError  : SocketError = ... # 0x15
    TemporaryError           : SocketError = ... # 0x16
    UnknownSocketError       : SocketError = ... # -0x1

    class SocketOption(object): ...
    LowDelayOption           : SocketOption = ... # 0x0
    KeepAliveOption          : SocketOption = ... # 0x1
    MulticastTtlOption       : SocketOption = ... # 0x2
    MulticastLoopbackOption  : SocketOption = ... # 0x3
    TypeOfServiceOption      : SocketOption = ... # 0x4
    SendBufferSizeSocketOption: SocketOption = ... # 0x5
    ReceiveBufferSizeSocketOption: SocketOption = ... # 0x6
    PathMtuSocketOption      : SocketOption = ... # 0x7

    class SocketState(object): ...
    UnconnectedState         : SocketState = ... # 0x0
    HostLookupState          : SocketState = ... # 0x1
    ConnectingState          : SocketState = ... # 0x2
    ConnectedState           : SocketState = ... # 0x3
    BoundState               : SocketState = ... # 0x4
    ListeningState           : SocketState = ... # 0x5
    ClosingState             : SocketState = ... # 0x6

    class SocketType(object): ...
    TcpSocket                : SocketType = ... # 0x0
    UdpSocket                : SocketType = ... # 0x1
    SctpSocket               : SocketType = ... # 0x2
    UnknownSocketType        : SocketType = ... # -0x1

    def __init__(self, socketType: PySide2.QtNetwork.QAbstractSocket.SocketType, parent: PySide2.QtCore.QObject): ...

    def abort(self): ...
    def atEnd(self) -> bool: ...
    @typing.overload
    def bind(self, address: PySide2.QtNetwork.QHostAddress, port: int = ..., mode: PySide2.QtNetwork.QAbstractSocket.BindMode = ...) -> bool: ...
    @typing.overload
    def bind(self, port: int = ..., mode: PySide2.QtNetwork.QAbstractSocket.BindMode = ...) -> bool: ...
    def bytesAvailable(self) -> int: ...
    def bytesToWrite(self) -> int: ...
    def canReadLine(self) -> bool: ...
    def close(self): ...
    @typing.overload
    def connectToHost(self, address: PySide2.QtNetwork.QHostAddress, port: int, mode: PySide2.QtCore.QIODevice.OpenMode = ...): ...
    @typing.overload
    def connectToHost(self, hostName: str, port: int, mode: PySide2.QtCore.QIODevice.OpenMode = ..., protocol: PySide2.QtNetwork.QAbstractSocket.NetworkLayerProtocol = ...): ...
    def disconnectFromHost(self): ...
    def error(self) -> PySide2.QtNetwork.QAbstractSocket.SocketError: ...
    def flush(self) -> bool: ...
    def isSequential(self) -> bool: ...
    def isValid(self) -> bool: ...
    def localAddress(self) -> PySide2.QtNetwork.QHostAddress: ...
    def localPort(self) -> int: ...
    def pauseMode(self) -> PySide2.QtNetwork.QAbstractSocket.PauseModes: ...
    def peerAddress(self) -> PySide2.QtNetwork.QHostAddress: ...
    def peerName(self) -> str: ...
    def peerPort(self) -> int: ...
    def protocolTag(self) -> str: ...
    def proxy(self) -> PySide2.QtNetwork.QNetworkProxy: ...
    def readBufferSize(self) -> int: ...
    def readData(self, data: str, maxlen: int) -> int: ...
    def readLineData(self, data: str, maxlen: int) -> int: ...
    def resume(self): ...
    def setLocalAddress(self, address: PySide2.QtNetwork.QHostAddress): ...
    def setLocalPort(self, port: int): ...
    def setPauseMode(self, pauseMode: PySide2.QtNetwork.QAbstractSocket.PauseModes): ...
    def setPeerAddress(self, address: PySide2.QtNetwork.QHostAddress): ...
    def setPeerName(self, name: str): ...
    def setPeerPort(self, port: int): ...
    def setProtocolTag(self, tag: str): ...
    def setProxy(self, networkProxy: PySide2.QtNetwork.QNetworkProxy): ...
    def setReadBufferSize(self, size: int): ...
    def setSocketDescriptor(self, socketDescriptor: int, state: PySide2.QtNetwork.QAbstractSocket.SocketState = ..., openMode: PySide2.QtCore.QIODevice.OpenMode = ...) -> bool: ...
    def setSocketError(self, socketError: PySide2.QtNetwork.QAbstractSocket.SocketError): ...
    def setSocketOption(self, option: PySide2.QtNetwork.QAbstractSocket.SocketOption, value: typing.Any): ...
    def setSocketState(self, state: PySide2.QtNetwork.QAbstractSocket.SocketState): ...
    def socketDescriptor(self) -> int: ...
    def socketOption(self, option: PySide2.QtNetwork.QAbstractSocket.SocketOption) -> typing.Any: ...
    def socketType(self) -> PySide2.QtNetwork.QAbstractSocket.SocketType: ...
    def state(self) -> PySide2.QtNetwork.QAbstractSocket.SocketState: ...
    def waitForBytesWritten(self, msecs: int = ...) -> bool: ...
    def waitForConnected(self, msecs: int = ...) -> bool: ...
    def waitForDisconnected(self, msecs: int = ...) -> bool: ...
    def waitForReadyRead(self, msecs: int = ...) -> bool: ...
    def writeData(self, data: str, len: int) -> int: ...


class QAuthenticator(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QAuthenticator): ...

    def __copy__(self): ...
    def isNull(self) -> bool: ...
    def option(self, opt: str) -> typing.Any: ...
    def options(self) -> typing.Dict: ...
    def password(self) -> str: ...
    def realm(self) -> str: ...
    def setOption(self, opt: str, value: typing.Any): ...
    def setPassword(self, password: str): ...
    def setRealm(self, realm: str): ...
    def setUser(self, user: str): ...
    def user(self) -> str: ...


class QDnsDomainNameRecord(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QDnsDomainNameRecord): ...

    def __copy__(self): ...
    def name(self) -> str: ...
    def swap(self, other: PySide2.QtNetwork.QDnsDomainNameRecord): ...
    def timeToLive(self) -> int: ...
    def value(self) -> str: ...


class QDnsHostAddressRecord(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QDnsHostAddressRecord): ...

    def __copy__(self): ...
    def name(self) -> str: ...
    def swap(self, other: PySide2.QtNetwork.QDnsHostAddressRecord): ...
    def timeToLive(self) -> int: ...
    def value(self) -> PySide2.QtNetwork.QHostAddress: ...


class QDnsLookup(PySide2.QtCore.QObject):

    class Error(object): ...
    NoError                  : Error = ... # 0x0
    ResolverError            : Error = ... # 0x1
    OperationCancelledError  : Error = ... # 0x2
    InvalidRequestError      : Error = ... # 0x3
    InvalidReplyError        : Error = ... # 0x4
    ServerFailureError       : Error = ... # 0x5
    ServerRefusedError       : Error = ... # 0x6
    NotFoundError            : Error = ... # 0x7

    class Type(object): ...
    A                        : Type = ... # 0x1
    AAAA                     : Type = ... # 0x1c
    ANY                      : Type = ... # 0xff
    CNAME                    : Type = ... # 0x5
    MX                       : Type = ... # 0xf
    NS                       : Type = ... # 0x2
    PTR                      : Type = ... # 0xc
    SRV                      : Type = ... # 0x21
    TXT                      : Type = ... # 0x10

    @typing.overload
    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...
    @typing.overload
    def __init__(self, type: PySide2.QtNetwork.QDnsLookup.Type, name: str, nameserver: PySide2.QtNetwork.QHostAddress, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...
    @typing.overload
    def __init__(self, type: PySide2.QtNetwork.QDnsLookup.Type, name: str, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def abort(self): ...
    def canonicalNameRecords(self) -> typing.List[PySide2.QtNetwork.QDnsDomainNameRecord]: ...
    def error(self) -> PySide2.QtNetwork.QDnsLookup.Error: ...
    def errorString(self) -> str: ...
    def hostAddressRecords(self) -> typing.List[PySide2.QtNetwork.QDnsHostAddressRecord]: ...
    def isFinished(self) -> bool: ...
    def lookup(self): ...
    def mailExchangeRecords(self) -> typing.List[PySide2.QtNetwork.QDnsMailExchangeRecord]: ...
    def name(self) -> str: ...
    def nameServerRecords(self) -> typing.List[PySide2.QtNetwork.QDnsDomainNameRecord]: ...
    def nameserver(self) -> PySide2.QtNetwork.QHostAddress: ...
    def pointerRecords(self) -> typing.List[PySide2.QtNetwork.QDnsDomainNameRecord]: ...
    def serviceRecords(self) -> typing.List[PySide2.QtNetwork.QDnsServiceRecord]: ...
    def setName(self, name: str): ...
    def setNameserver(self, nameserver: PySide2.QtNetwork.QHostAddress): ...
    def setType(self, arg__1: PySide2.QtNetwork.QDnsLookup.Type): ...
    def textRecords(self) -> typing.List[PySide2.QtNetwork.QDnsTextRecord]: ...
    def type(self) -> PySide2.QtNetwork.QDnsLookup.Type: ...


class QDnsMailExchangeRecord(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QDnsMailExchangeRecord): ...

    def __copy__(self): ...
    def exchange(self) -> str: ...
    def name(self) -> str: ...
    def preference(self) -> int: ...
    def swap(self, other: PySide2.QtNetwork.QDnsMailExchangeRecord): ...
    def timeToLive(self) -> int: ...


class QDnsServiceRecord(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QDnsServiceRecord): ...

    def __copy__(self): ...
    def name(self) -> str: ...
    def port(self) -> int: ...
    def priority(self) -> int: ...
    def swap(self, other: PySide2.QtNetwork.QDnsServiceRecord): ...
    def target(self) -> str: ...
    def timeToLive(self) -> int: ...
    def weight(self) -> int: ...


class QDnsTextRecord(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QDnsTextRecord): ...

    def __copy__(self): ...
    def name(self) -> str: ...
    def swap(self, other: PySide2.QtNetwork.QDnsTextRecord): ...
    def timeToLive(self) -> int: ...
    def values(self) -> typing.List[PySide2.QtCore.QByteArray]: ...


class QDtls(PySide2.QtCore.QObject):

    class HandshakeState(object): ...
    HandshakeNotStarted      : HandshakeState = ... # 0x0
    HandshakeInProgress      : HandshakeState = ... # 0x1
    PeerVerificationFailed   : HandshakeState = ... # 0x2
    HandshakeComplete        : HandshakeState = ... # 0x3

    def __init__(self, mode: PySide2.QtNetwork.QSslSocket.SslMode, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def abortHandshake(self, socket: PySide2.QtNetwork.QUdpSocket) -> bool: ...
    def decryptDatagram(self, socket: PySide2.QtNetwork.QUdpSocket, dgram: PySide2.QtCore.QByteArray) -> PySide2.QtCore.QByteArray: ...
    def doHandshake(self, socket: PySide2.QtNetwork.QUdpSocket, dgram: PySide2.QtCore.QByteArray = ...) -> bool: ...
    def dtlsConfiguration(self) -> PySide2.QtNetwork.QSslConfiguration: ...
    def dtlsError(self) -> PySide2.QtNetwork.QDtlsError: ...
    def dtlsErrorString(self) -> str: ...
    def handleTimeout(self, socket: PySide2.QtNetwork.QUdpSocket) -> bool: ...
    def handshakeState(self) -> PySide2.QtNetwork.QDtls.HandshakeState: ...
    def ignoreVerificationErrors(self, errorsToIgnore: typing.List[PySide2.QtNetwork.QSslError]): ...
    def isConnectionEncrypted(self) -> bool: ...
    def mtuHint(self) -> int: ...
    def peerAddress(self) -> PySide2.QtNetwork.QHostAddress: ...
    def peerPort(self) -> int: ...
    def peerVerificationErrors(self) -> typing.List[PySide2.QtNetwork.QSslError]: ...
    def peerVerificationName(self) -> str: ...
    def resumeHandshake(self, socket: PySide2.QtNetwork.QUdpSocket) -> bool: ...
    def sessionCipher(self) -> PySide2.QtNetwork.QSslCipher: ...
    def sessionProtocol(self) -> PySide2.QtNetwork.QSsl.SslProtocol: ...
    def setDtlsConfiguration(self, configuration: PySide2.QtNetwork.QSslConfiguration) -> bool: ...
    def setMtuHint(self, mtuHint: int): ...
    def setPeer(self, address: PySide2.QtNetwork.QHostAddress, port: int, verificationName: str = ...) -> bool: ...
    def setPeerVerificationName(self, name: str) -> bool: ...
    def shutdown(self, socket: PySide2.QtNetwork.QUdpSocket) -> bool: ...
    def sslMode(self) -> PySide2.QtNetwork.QSslSocket.SslMode: ...
    def writeDatagramEncrypted(self, socket: PySide2.QtNetwork.QUdpSocket, dgram: PySide2.QtCore.QByteArray) -> int: ...


class QDtlsError(object): ...


class QHostAddress(Shiboken.Object):

    class ConversionMode(object): ...

    class ConversionModeFlag(object): ...
    ConvertV4MappedToIPv4    : ConversionModeFlag = ... # 0x1
    ConvertV4CompatToIPv4    : ConversionModeFlag = ... # 0x2
    ConvertUnspecifiedAddress: ConversionModeFlag = ... # 0x4
    ConvertLocalHost         : ConversionModeFlag = ... # 0x8
    TolerantConversion       : ConversionModeFlag = ... # 0xff
    StrictConversion         : ConversionModeFlag = ... # 0x0

    class SpecialAddress(object): ...
    Null                     : SpecialAddress = ... # 0x0
    Broadcast                : SpecialAddress = ... # 0x1
    LocalHost                : SpecialAddress = ... # 0x2
    LocalHostIPv6            : SpecialAddress = ... # 0x3
    Any                      : SpecialAddress = ... # 0x4
    AnyIPv6                  : SpecialAddress = ... # 0x5
    AnyIPv4                  : SpecialAddress = ... # 0x6

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, address: PySide2.QtNetwork.QHostAddress.SpecialAddress): ...
    @typing.overload
    def __init__(self, address: str): ...
    @typing.overload
    def __init__(self, copy: PySide2.QtNetwork.QHostAddress): ...
    @typing.overload
    def __init__(self, ip4Addr: int): ...
    @typing.overload
    def __init__(self, ip6Addr: PySide2.QtNetwork.QIPv6Address): ...

    def __copy__(self): ...
    def __lshift__(self, arg__1: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...
    def __rshift__(self, arg__1: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...
    def clear(self): ...
    def isBroadcast(self) -> bool: ...
    def isEqual(self, address: PySide2.QtNetwork.QHostAddress, mode: PySide2.QtNetwork.QHostAddress.ConversionMode = ...) -> bool: ...
    def isGlobal(self) -> bool: ...
    @typing.overload
    def isInSubnet(self, subnet: PySide2.QtNetwork.QHostAddress, netmask: int) -> bool: ...
    @typing.overload
    def isInSubnet(self, subnet: typing.Tuple) -> bool: ...
    def isLinkLocal(self) -> bool: ...
    def isLoopback(self) -> bool: ...
    def isMulticast(self) -> bool: ...
    def isNull(self) -> bool: ...
    def isSiteLocal(self) -> bool: ...
    def isUniqueLocalUnicast(self) -> bool: ...
    @staticmethod
    def parseSubnet(subnet: str) -> typing.Tuple: ...
    def protocol(self) -> PySide2.QtNetwork.QAbstractSocket.NetworkLayerProtocol: ...
    def scopeId(self) -> str: ...
    @typing.overload
    def setAddress(self, address: PySide2.QtNetwork.QHostAddress.SpecialAddress): ...
    @typing.overload
    def setAddress(self, address: str) -> bool: ...
    @typing.overload
    def setAddress(self, ip4Addr: int): ...
    @typing.overload
    def setAddress(self, ip6Addr: PySide2.QtNetwork.QIPv6Address): ...
    def setScopeId(self, id: str): ...
    def swap(self, other: PySide2.QtNetwork.QHostAddress): ...
    @typing.overload
    def toIPv4Address(self) -> int: ...
    @typing.overload
    def toIPv4Address(self, ok: bool) -> int: ...
    def toIPv6Address(self) -> PySide2.QtNetwork.QIPv6Address: ...
    def toString(self) -> str: ...


class QHostInfo(Shiboken.Object):

    class HostInfoError(object): ...
    NoError                  : HostInfoError = ... # 0x0
    HostNotFound             : HostInfoError = ... # 0x1
    UnknownError             : HostInfoError = ... # 0x2

    @typing.overload
    def __init__(self, d: PySide2.QtNetwork.QHostInfo): ...
    @typing.overload
    def __init__(self, lookupId: int = ...): ...

    def __copy__(self): ...
    @staticmethod
    def abortHostLookup(lookupId: int): ...
    def addresses(self) -> typing.List[PySide2.QtNetwork.QHostAddress]: ...
    def error(self) -> PySide2.QtNetwork.QHostInfo.HostInfoError: ...
    def errorString(self) -> str: ...
    @staticmethod
    def fromName(name: str) -> PySide2.QtNetwork.QHostInfo: ...
    def hostName(self) -> str: ...
    @staticmethod
    def localDomainName() -> str: ...
    @staticmethod
    def localHostName() -> str: ...
    def lookupId(self) -> int: ...
    def setAddresses(self, addresses: typing.List[PySide2.QtNetwork.QHostAddress]): ...
    def setError(self, error: PySide2.QtNetwork.QHostInfo.HostInfoError): ...
    def setErrorString(self, errorString: str): ...
    def setHostName(self, name: str): ...
    def setLookupId(self, id: int): ...
    def swap(self, other: PySide2.QtNetwork.QHostInfo): ...


class QHstsPolicy(Shiboken.Object):

    class PolicyFlag(object): ...
    IncludeSubDomains        : PolicyFlag = ... # 0x1

    class PolicyFlags(object): ...

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, expiry: PySide2.QtCore.QDateTime, flags: PySide2.QtNetwork.QHstsPolicy.PolicyFlags, host: str, mode: PySide2.QtCore.QUrl.ParsingMode = ...): ...
    @typing.overload
    def __init__(self, rhs: PySide2.QtNetwork.QHstsPolicy): ...

    def __copy__(self): ...
    def expiry(self) -> PySide2.QtCore.QDateTime: ...
    def host(self, options: PySide2.QtCore.QUrl.ComponentFormattingOption = ...) -> str: ...
    def includesSubDomains(self) -> bool: ...
    def isExpired(self) -> bool: ...
    def setExpiry(self, expiry: PySide2.QtCore.QDateTime): ...
    def setHost(self, host: str, mode: PySide2.QtCore.QUrl.ParsingMode = ...): ...
    def setIncludesSubDomains(self, include: bool): ...
    def swap(self, other: PySide2.QtNetwork.QHstsPolicy): ...


class QHttpMultiPart(PySide2.QtCore.QObject):

    class ContentType(object): ...
    MixedType                : ContentType = ... # 0x0
    RelatedType              : ContentType = ... # 0x1
    FormDataType             : ContentType = ... # 0x2
    AlternativeType          : ContentType = ... # 0x3

    @typing.overload
    def __init__(self, contentType: PySide2.QtNetwork.QHttpMultiPart.ContentType, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...
    @typing.overload
    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def append(self, httpPart: PySide2.QtNetwork.QHttpPart): ...
    def boundary(self) -> PySide2.QtCore.QByteArray: ...
    def setBoundary(self, boundary: PySide2.QtCore.QByteArray): ...
    def setContentType(self, contentType: PySide2.QtNetwork.QHttpMultiPart.ContentType): ...


class QHttpPart(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QHttpPart): ...

    def __copy__(self): ...
    def setBody(self, body: PySide2.QtCore.QByteArray): ...
    def setBodyDevice(self, device: PySide2.QtCore.QIODevice): ...
    def setHeader(self, header: PySide2.QtNetwork.QNetworkRequest.KnownHeaders, value: typing.Any): ...
    def setRawHeader(self, headerName: PySide2.QtCore.QByteArray, headerValue: PySide2.QtCore.QByteArray): ...
    def swap(self, other: PySide2.QtNetwork.QHttpPart): ...


class QIPv6Address(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, QIPv6Address: PySide2.QtNetwork.QIPv6Address): ...

    def __copy__(self): ...


class QLocalServer(PySide2.QtCore.QObject):

    class SocketOption(object): ...
    NoOptions                : SocketOption = ... # 0x0
    UserAccessOption         : SocketOption = ... # 0x1
    GroupAccessOption        : SocketOption = ... # 0x2
    OtherAccessOption        : SocketOption = ... # 0x4
    WorldAccessOption        : SocketOption = ... # 0x7

    class SocketOptions(object): ...

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def close(self): ...
    def errorString(self) -> str: ...
    def fullServerName(self) -> str: ...
    def hasPendingConnections(self) -> bool: ...
    def incomingConnection(self, socketDescriptor: int): ...
    def isListening(self) -> bool: ...
    @typing.overload
    def listen(self, name: str) -> bool: ...
    @typing.overload
    def listen(self, socketDescriptor: int) -> bool: ...
    def maxPendingConnections(self) -> int: ...
    def nextPendingConnection(self) -> PySide2.QtNetwork.QLocalSocket: ...
    @staticmethod
    def removeServer(name: str) -> bool: ...
    def serverError(self) -> PySide2.QtNetwork.QAbstractSocket.SocketError: ...
    def serverName(self) -> str: ...
    def setMaxPendingConnections(self, numConnections: int): ...
    def setSocketOptions(self, options: PySide2.QtNetwork.QLocalServer.SocketOptions): ...
    def socketDescriptor(self) -> int: ...
    def socketOptions(self) -> PySide2.QtNetwork.QLocalServer.SocketOptions: ...
    def waitForNewConnection(self, msec: int, timedOut: bool) -> bool: ...


class QLocalSocket(PySide2.QtCore.QIODevice):

    class LocalSocketError(object): ...
    ConnectionRefusedError   : LocalSocketError = ... # 0x0
    PeerClosedError          : LocalSocketError = ... # 0x1
    ServerNotFoundError      : LocalSocketError = ... # 0x2
    SocketAccessError        : LocalSocketError = ... # 0x3
    SocketResourceError      : LocalSocketError = ... # 0x4
    SocketTimeoutError       : LocalSocketError = ... # 0x5
    DatagramTooLargeError    : LocalSocketError = ... # 0x6
    ConnectionError          : LocalSocketError = ... # 0x7
    UnsupportedSocketOperationError: LocalSocketError = ... # 0xa
    UnknownSocketError       : LocalSocketError = ... # -0x1
    OperationError           : LocalSocketError = ... # 0x13

    class LocalSocketState(object): ...
    UnconnectedState         : LocalSocketState = ... # 0x0
    ConnectingState          : LocalSocketState = ... # 0x2
    ConnectedState           : LocalSocketState = ... # 0x3
    ClosingState             : LocalSocketState = ... # 0x6

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def abort(self): ...
    def bytesAvailable(self) -> int: ...
    def bytesToWrite(self) -> int: ...
    def canReadLine(self) -> bool: ...
    def close(self): ...
    @typing.overload
    def connectToServer(self, name: str, openMode: PySide2.QtCore.QIODevice.OpenMode = ...): ...
    @typing.overload
    def connectToServer(self, openMode: PySide2.QtCore.QIODevice.OpenMode = ...): ...
    def disconnectFromServer(self): ...
    def error(self) -> PySide2.QtNetwork.QLocalSocket.LocalSocketError: ...
    def flush(self) -> bool: ...
    def fullServerName(self) -> str: ...
    def isSequential(self) -> bool: ...
    def isValid(self) -> bool: ...
    def open(self, openMode: PySide2.QtCore.QIODevice.OpenMode = ...) -> bool: ...
    def readBufferSize(self) -> int: ...
    def readData(self, arg__1: str, arg__2: int) -> int: ...
    def serverName(self) -> str: ...
    def setReadBufferSize(self, size: int): ...
    def setServerName(self, name: str): ...
    def setSocketDescriptor(self, socketDescriptor: int, socketState: PySide2.QtNetwork.QLocalSocket.LocalSocketState = ..., openMode: PySide2.QtCore.QIODevice.OpenMode = ...) -> bool: ...
    def socketDescriptor(self) -> int: ...
    def state(self) -> PySide2.QtNetwork.QLocalSocket.LocalSocketState: ...
    def waitForBytesWritten(self, msecs: int = ...) -> bool: ...
    def waitForConnected(self, msecs: int = ...) -> bool: ...
    def waitForDisconnected(self, msecs: int = ...) -> bool: ...
    def waitForReadyRead(self, msecs: int = ...) -> bool: ...
    def writeData(self, arg__1: str, arg__2: int) -> int: ...


class QNetworkAccessManager(PySide2.QtCore.QObject):

    class NetworkAccessibility(object): ...
    UnknownAccessibility     : NetworkAccessibility = ... # -0x1
    NotAccessible            : NetworkAccessibility = ... # 0x0
    Accessible               : NetworkAccessibility = ... # 0x1

    class Operation(object): ...
    HeadOperation            : Operation = ... # 0x1
    GetOperation             : Operation = ... # 0x2
    PutOperation             : Operation = ... # 0x3
    PostOperation            : Operation = ... # 0x4
    DeleteOperation          : Operation = ... # 0x5
    CustomOperation          : Operation = ... # 0x6
    UnknownOperation         : Operation = ... # 0x0

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def activeConfiguration(self) -> PySide2.QtNetwork.QNetworkConfiguration: ...
    def addStrictTransportSecurityHosts(self, knownHosts: typing.List[PySide2.QtNetwork.QHstsPolicy]): ...
    def cache(self) -> PySide2.QtNetwork.QAbstractNetworkCache: ...
    def clearAccessCache(self): ...
    def clearConnectionCache(self): ...
    def configuration(self) -> PySide2.QtNetwork.QNetworkConfiguration: ...
    def connectToHost(self, hostName: str, port: int = ...): ...
    @typing.overload
    def connectToHostEncrypted(self, hostName: str, port: int, sslConfiguration: PySide2.QtNetwork.QSslConfiguration, peerName: str): ...
    @typing.overload
    def connectToHostEncrypted(self, hostName: str, port: int = ..., sslConfiguration: PySide2.QtNetwork.QSslConfiguration = ...): ...
    def cookieJar(self) -> PySide2.QtNetwork.QNetworkCookieJar: ...
    def createRequest(self, op: PySide2.QtNetwork.QNetworkAccessManager.Operation, request: PySide2.QtNetwork.QNetworkRequest, outgoingData: typing.Optional[PySide2.QtCore.QIODevice] = ...) -> PySide2.QtNetwork.QNetworkReply: ...
    def deleteResource(self, request: PySide2.QtNetwork.QNetworkRequest) -> PySide2.QtNetwork.QNetworkReply: ...
    def enableStrictTransportSecurityStore(self, enabled: bool, storeDir: str = ...): ...
    def get(self, request: PySide2.QtNetwork.QNetworkRequest) -> PySide2.QtNetwork.QNetworkReply: ...
    def head(self, request: PySide2.QtNetwork.QNetworkRequest) -> PySide2.QtNetwork.QNetworkReply: ...
    def isStrictTransportSecurityEnabled(self) -> bool: ...
    def isStrictTransportSecurityStoreEnabled(self) -> bool: ...
    def networkAccessible(self) -> PySide2.QtNetwork.QNetworkAccessManager.NetworkAccessibility: ...
    @typing.overload
    def post(self, request: PySide2.QtNetwork.QNetworkRequest, data: PySide2.QtCore.QByteArray) -> PySide2.QtNetwork.QNetworkReply: ...
    @typing.overload
    def post(self, request: PySide2.QtNetwork.QNetworkRequest, data: PySide2.QtCore.QIODevice) -> PySide2.QtNetwork.QNetworkReply: ...
    @typing.overload
    def post(self, request: PySide2.QtNetwork.QNetworkRequest, multiPart: PySide2.QtNetwork.QHttpMultiPart) -> PySide2.QtNetwork.QNetworkReply: ...
    def proxy(self) -> PySide2.QtNetwork.QNetworkProxy: ...
    def proxyFactory(self) -> PySide2.QtNetwork.QNetworkProxyFactory: ...
    @typing.overload
    def put(self, request: PySide2.QtNetwork.QNetworkRequest, data: PySide2.QtCore.QByteArray) -> PySide2.QtNetwork.QNetworkReply: ...
    @typing.overload
    def put(self, request: PySide2.QtNetwork.QNetworkRequest, data: PySide2.QtCore.QIODevice) -> PySide2.QtNetwork.QNetworkReply: ...
    @typing.overload
    def put(self, request: PySide2.QtNetwork.QNetworkRequest, multiPart: PySide2.QtNetwork.QHttpMultiPart) -> PySide2.QtNetwork.QNetworkReply: ...
    def redirectPolicy(self) -> PySide2.QtNetwork.QNetworkRequest.RedirectPolicy: ...
    @typing.overload
    def sendCustomRequest(self, request: PySide2.QtNetwork.QNetworkRequest, verb: PySide2.QtCore.QByteArray, data: PySide2.QtCore.QByteArray) -> PySide2.QtNetwork.QNetworkReply: ...
    @typing.overload
    def sendCustomRequest(self, request: PySide2.QtNetwork.QNetworkRequest, verb: PySide2.QtCore.QByteArray, data: typing.Optional[PySide2.QtCore.QIODevice] = ...) -> PySide2.QtNetwork.QNetworkReply: ...
    @typing.overload
    def sendCustomRequest(self, request: PySide2.QtNetwork.QNetworkRequest, verb: PySide2.QtCore.QByteArray, multiPart: PySide2.QtNetwork.QHttpMultiPart) -> PySide2.QtNetwork.QNetworkReply: ...
    def setCache(self, cache: PySide2.QtNetwork.QAbstractNetworkCache): ...
    def setConfiguration(self, config: PySide2.QtNetwork.QNetworkConfiguration): ...
    def setCookieJar(self, cookieJar: PySide2.QtNetwork.QNetworkCookieJar): ...
    def setNetworkAccessible(self, accessible: PySide2.QtNetwork.QNetworkAccessManager.NetworkAccessibility): ...
    def setProxy(self, proxy: PySide2.QtNetwork.QNetworkProxy): ...
    def setProxyFactory(self, factory: PySide2.QtNetwork.QNetworkProxyFactory): ...
    def setRedirectPolicy(self, policy: PySide2.QtNetwork.QNetworkRequest.RedirectPolicy): ...
    def setStrictTransportSecurityEnabled(self, enabled: bool): ...
    def strictTransportSecurityHosts(self) -> typing.List[PySide2.QtNetwork.QHstsPolicy]: ...
    def supportedSchemes(self) -> typing.List[str]: ...
    def supportedSchemesImplementation(self) -> typing.List[str]: ...


class QNetworkAddressEntry(Shiboken.Object):

    class DnsEligibilityStatus(object): ...
    DnsEligibilityUnknown    : DnsEligibilityStatus = ... # -0x1
    DnsIneligible            : DnsEligibilityStatus = ... # 0x0
    DnsEligible              : DnsEligibilityStatus = ... # 0x1

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QNetworkAddressEntry): ...

    def __copy__(self): ...
    def broadcast(self) -> PySide2.QtNetwork.QHostAddress: ...
    def clearAddressLifetime(self): ...
    def dnsEligibility(self) -> PySide2.QtNetwork.QNetworkAddressEntry.DnsEligibilityStatus: ...
    def ip(self) -> PySide2.QtNetwork.QHostAddress: ...
    def isLifetimeKnown(self) -> bool: ...
    def isPermanent(self) -> bool: ...
    def isTemporary(self) -> bool: ...
    def netmask(self) -> PySide2.QtNetwork.QHostAddress: ...
    def prefixLength(self) -> int: ...
    def setBroadcast(self, newBroadcast: PySide2.QtNetwork.QHostAddress): ...
    def setDnsEligibility(self, status: PySide2.QtNetwork.QNetworkAddressEntry.DnsEligibilityStatus): ...
    def setIp(self, newIp: PySide2.QtNetwork.QHostAddress): ...
    def setNetmask(self, newNetmask: PySide2.QtNetwork.QHostAddress): ...
    def setPrefixLength(self, length: int): ...
    def swap(self, other: PySide2.QtNetwork.QNetworkAddressEntry): ...


class QNetworkCacheMetaData(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QNetworkCacheMetaData): ...

    def __copy__(self): ...
    def __lshift__(self, arg__1: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...
    def __rshift__(self, arg__1: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...
    def attributes(self) -> typing.Dict: ...
    def expirationDate(self) -> PySide2.QtCore.QDateTime: ...
    def isValid(self) -> bool: ...
    def lastModified(self) -> PySide2.QtCore.QDateTime: ...
    def rawHeaders(self) -> typing.List[typing.Tuple]: ...
    def saveToDisk(self) -> bool: ...
    def setAttributes(self, attributes: typing.Dict): ...
    def setExpirationDate(self, dateTime: PySide2.QtCore.QDateTime): ...
    def setLastModified(self, dateTime: PySide2.QtCore.QDateTime): ...
    def setRawHeaders(self, headers: typing.List[typing.Tuple]): ...
    def setSaveToDisk(self, allow: bool): ...
    def setUrl(self, url: PySide2.QtCore.QUrl): ...
    def swap(self, other: PySide2.QtNetwork.QNetworkCacheMetaData): ...
    def url(self) -> PySide2.QtCore.QUrl: ...


class QNetworkConfiguration(Shiboken.Object):

    class BearerType(object): ...
    BearerUnknown            : BearerType = ... # 0x0
    BearerEthernet           : BearerType = ... # 0x1
    BearerWLAN               : BearerType = ... # 0x2
    Bearer2G                 : BearerType = ... # 0x3
    BearerCDMA2000           : BearerType = ... # 0x4
    BearerWCDMA              : BearerType = ... # 0x5
    BearerHSPA               : BearerType = ... # 0x6
    BearerBluetooth          : BearerType = ... # 0x7
    BearerWiMAX              : BearerType = ... # 0x8
    BearerEVDO               : BearerType = ... # 0x9
    BearerLTE                : BearerType = ... # 0xa
    Bearer3G                 : BearerType = ... # 0xb
    Bearer4G                 : BearerType = ... # 0xc

    class Purpose(object): ...
    UnknownPurpose           : Purpose = ... # 0x0
    PublicPurpose            : Purpose = ... # 0x1
    PrivatePurpose           : Purpose = ... # 0x2
    ServiceSpecificPurpose   : Purpose = ... # 0x3

    class StateFlag(object): ...
    Undefined                : StateFlag = ... # 0x1
    Defined                  : StateFlag = ... # 0x2
    Discovered               : StateFlag = ... # 0x6
    Active                   : StateFlag = ... # 0xe

    class StateFlags(object): ...

    class Type(object): ...
    InternetAccessPoint      : Type = ... # 0x0
    ServiceNetwork           : Type = ... # 0x1
    UserChoice               : Type = ... # 0x2
    Invalid                  : Type = ... # 0x3

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QNetworkConfiguration): ...

    def __copy__(self): ...
    def bearerType(self) -> PySide2.QtNetwork.QNetworkConfiguration.BearerType: ...
    def bearerTypeFamily(self) -> PySide2.QtNetwork.QNetworkConfiguration.BearerType: ...
    def bearerTypeName(self) -> str: ...
    def children(self) -> typing.List[PySide2.QtNetwork.QNetworkConfiguration]: ...
    def connectTimeout(self) -> int: ...
    def identifier(self) -> str: ...
    def isRoamingAvailable(self) -> bool: ...
    def isValid(self) -> bool: ...
    def name(self) -> str: ...
    def purpose(self) -> PySide2.QtNetwork.QNetworkConfiguration.Purpose: ...
    def setConnectTimeout(self, timeout: int) -> bool: ...
    def state(self) -> PySide2.QtNetwork.QNetworkConfiguration.StateFlags: ...
    def swap(self, other: PySide2.QtNetwork.QNetworkConfiguration): ...
    def type(self) -> PySide2.QtNetwork.QNetworkConfiguration.Type: ...


class QNetworkConfigurationManager(PySide2.QtCore.QObject):

    class Capabilities(object): ...

    class Capability(object): ...
    CanStartAndStopInterfaces: Capability = ... # 0x1
    DirectConnectionRouting  : Capability = ... # 0x2
    SystemSessionSupport     : Capability = ... # 0x4
    ApplicationLevelRoaming  : Capability = ... # 0x8
    ForcedRoaming            : Capability = ... # 0x10
    DataStatistics           : Capability = ... # 0x20
    NetworkSessionRequired   : Capability = ... # 0x40

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def allConfigurations(self, flags: PySide2.QtNetwork.QNetworkConfiguration.StateFlags = ...) -> typing.List[PySide2.QtNetwork.QNetworkConfiguration]: ...
    def capabilities(self) -> PySide2.QtNetwork.QNetworkConfigurationManager.Capabilities: ...
    def configurationFromIdentifier(self, identifier: str) -> PySide2.QtNetwork.QNetworkConfiguration: ...
    def defaultConfiguration(self) -> PySide2.QtNetwork.QNetworkConfiguration: ...
    def isOnline(self) -> bool: ...
    def updateConfigurations(self): ...


class QNetworkCookie(Shiboken.Object):

    class RawForm(object): ...
    NameAndValueOnly         : RawForm = ... # 0x0
    Full                     : RawForm = ... # 0x1

    @typing.overload
    def __init__(self, name: PySide2.QtCore.QByteArray = ..., value: PySide2.QtCore.QByteArray = ...): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QNetworkCookie): ...

    def __copy__(self): ...
    def domain(self) -> str: ...
    def expirationDate(self) -> PySide2.QtCore.QDateTime: ...
    def hasSameIdentifier(self, other: PySide2.QtNetwork.QNetworkCookie) -> bool: ...
    def isHttpOnly(self) -> bool: ...
    def isSecure(self) -> bool: ...
    def isSessionCookie(self) -> bool: ...
    def name(self) -> PySide2.QtCore.QByteArray: ...
    def normalize(self, url: PySide2.QtCore.QUrl): ...
    @staticmethod
    def parseCookies(cookieString: PySide2.QtCore.QByteArray) -> typing.List[PySide2.QtNetwork.QNetworkCookie]: ...
    def path(self) -> str: ...
    def setDomain(self, domain: str): ...
    def setExpirationDate(self, date: PySide2.QtCore.QDateTime): ...
    def setHttpOnly(self, enable: bool): ...
    def setName(self, cookieName: PySide2.QtCore.QByteArray): ...
    def setPath(self, path: str): ...
    def setSecure(self, enable: bool): ...
    def setValue(self, value: PySide2.QtCore.QByteArray): ...
    def swap(self, other: PySide2.QtNetwork.QNetworkCookie): ...
    def toRawForm(self, form: PySide2.QtNetwork.QNetworkCookie.RawForm = ...) -> PySide2.QtCore.QByteArray: ...
    def value(self) -> PySide2.QtCore.QByteArray: ...


class QNetworkCookieJar(PySide2.QtCore.QObject):

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def allCookies(self) -> typing.List[PySide2.QtNetwork.QNetworkCookie]: ...
    def cookiesForUrl(self, url: PySide2.QtCore.QUrl) -> typing.List[PySide2.QtNetwork.QNetworkCookie]: ...
    def deleteCookie(self, cookie: PySide2.QtNetwork.QNetworkCookie) -> bool: ...
    def insertCookie(self, cookie: PySide2.QtNetwork.QNetworkCookie) -> bool: ...
    def setAllCookies(self, cookieList: typing.List[PySide2.QtNetwork.QNetworkCookie]): ...
    def setCookiesFromUrl(self, cookieList: typing.List[PySide2.QtNetwork.QNetworkCookie], url: PySide2.QtCore.QUrl) -> bool: ...
    def updateCookie(self, cookie: PySide2.QtNetwork.QNetworkCookie) -> bool: ...
    def validateCookie(self, cookie: PySide2.QtNetwork.QNetworkCookie, url: PySide2.QtCore.QUrl) -> bool: ...


class QNetworkDatagram(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, data: PySide2.QtCore.QByteArray, destinationAddress: PySide2.QtNetwork.QHostAddress = ..., port: int = ...): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QNetworkDatagram): ...

    def __copy__(self): ...
    def clear(self): ...
    def data(self) -> PySide2.QtCore.QByteArray: ...
    def destinationAddress(self) -> PySide2.QtNetwork.QHostAddress: ...
    def destinationPort(self) -> int: ...
    def hopLimit(self) -> int: ...
    def interfaceIndex(self) -> int: ...
    def isNull(self) -> bool: ...
    def isValid(self) -> bool: ...
    def makeReply(self, payload: PySide2.QtCore.QByteArray) -> PySide2.QtNetwork.QNetworkDatagram: ...
    def senderAddress(self) -> PySide2.QtNetwork.QHostAddress: ...
    def senderPort(self) -> int: ...
    def setData(self, data: PySide2.QtCore.QByteArray): ...
    def setDestination(self, address: PySide2.QtNetwork.QHostAddress, port: int): ...
    def setHopLimit(self, count: int): ...
    def setInterfaceIndex(self, index: int): ...
    def setSender(self, address: PySide2.QtNetwork.QHostAddress, port: int = ...): ...
    def swap(self, other: PySide2.QtNetwork.QNetworkDatagram): ...


class QNetworkDiskCache(PySide2.QtNetwork.QAbstractNetworkCache):

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def cacheDirectory(self) -> str: ...
    def cacheSize(self) -> int: ...
    def clear(self): ...
    def data(self, url: PySide2.QtCore.QUrl) -> PySide2.QtCore.QIODevice: ...
    def expire(self) -> int: ...
    def fileMetaData(self, fileName: str) -> PySide2.QtNetwork.QNetworkCacheMetaData: ...
    def insert(self, device: PySide2.QtCore.QIODevice): ...
    def maximumCacheSize(self) -> int: ...
    def metaData(self, url: PySide2.QtCore.QUrl) -> PySide2.QtNetwork.QNetworkCacheMetaData: ...
    def prepare(self, metaData: PySide2.QtNetwork.QNetworkCacheMetaData) -> PySide2.QtCore.QIODevice: ...
    def remove(self, url: PySide2.QtCore.QUrl) -> bool: ...
    def setCacheDirectory(self, cacheDir: str): ...
    def setMaximumCacheSize(self, size: int): ...
    def updateMetaData(self, metaData: PySide2.QtNetwork.QNetworkCacheMetaData): ...


class QNetworkInterface(Shiboken.Object):

    class InterfaceFlag(object): ...
    IsUp                     : InterfaceFlag = ... # 0x1
    IsRunning                : InterfaceFlag = ... # 0x2
    CanBroadcast             : InterfaceFlag = ... # 0x4
    IsLoopBack               : InterfaceFlag = ... # 0x8
    IsPointToPoint           : InterfaceFlag = ... # 0x10
    CanMulticast             : InterfaceFlag = ... # 0x20

    class InterfaceFlags(object): ...

    class InterfaceType(object): ...
    Loopback                 : InterfaceType = ... # 0x1
    Virtual                  : InterfaceType = ... # 0x2
    Ethernet                 : InterfaceType = ... # 0x3
    Slip                     : InterfaceType = ... # 0x4
    CanBus                   : InterfaceType = ... # 0x5
    Ppp                      : InterfaceType = ... # 0x6
    Fddi                     : InterfaceType = ... # 0x7
    Wifi                     : InterfaceType = ... # 0x8
    Ieee80211                : InterfaceType = ... # 0x8
    Phonet                   : InterfaceType = ... # 0x9
    Ieee802154               : InterfaceType = ... # 0xa
    SixLoWPAN                : InterfaceType = ... # 0xb
    Ieee80216                : InterfaceType = ... # 0xc
    Ieee1394                 : InterfaceType = ... # 0xd
    Unknown                  : InterfaceType = ... # 0x0

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QNetworkInterface): ...

    def __copy__(self): ...
    def addressEntries(self) -> typing.List[PySide2.QtNetwork.QNetworkAddressEntry]: ...
    @staticmethod
    def allAddresses() -> typing.List[PySide2.QtNetwork.QHostAddress]: ...
    @staticmethod
    def allInterfaces() -> typing.List[PySide2.QtNetwork.QNetworkInterface]: ...
    def flags(self) -> PySide2.QtNetwork.QNetworkInterface.InterfaceFlags: ...
    def hardwareAddress(self) -> str: ...
    def humanReadableName(self) -> str: ...
    def index(self) -> int: ...
    @staticmethod
    def interfaceFromIndex(index: int) -> PySide2.QtNetwork.QNetworkInterface: ...
    @staticmethod
    def interfaceFromName(name: str) -> PySide2.QtNetwork.QNetworkInterface: ...
    @staticmethod
    def interfaceIndexFromName(name: str) -> int: ...
    @staticmethod
    def interfaceNameFromIndex(index: int) -> str: ...
    def isValid(self) -> bool: ...
    def maximumTransmissionUnit(self) -> int: ...
    def name(self) -> str: ...
    def swap(self, other: PySide2.QtNetwork.QNetworkInterface): ...
    def type(self) -> PySide2.QtNetwork.QNetworkInterface.InterfaceType: ...


class QNetworkProxy(Shiboken.Object):

    class Capabilities(object): ...

    class Capability(object): ...
    TunnelingCapability      : Capability = ... # 0x1
    ListeningCapability      : Capability = ... # 0x2
    UdpTunnelingCapability   : Capability = ... # 0x4
    CachingCapability        : Capability = ... # 0x8
    HostNameLookupCapability : Capability = ... # 0x10
    SctpTunnelingCapability  : Capability = ... # 0x20
    SctpListeningCapability  : Capability = ... # 0x40

    class ProxyType(object): ...
    DefaultProxy             : ProxyType = ... # 0x0
    Socks5Proxy              : ProxyType = ... # 0x1
    NoProxy                  : ProxyType = ... # 0x2
    HttpProxy                : ProxyType = ... # 0x3
    HttpCachingProxy         : ProxyType = ... # 0x4
    FtpCachingProxy          : ProxyType = ... # 0x5

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QNetworkProxy): ...
    @typing.overload
    def __init__(self, type: PySide2.QtNetwork.QNetworkProxy.ProxyType, hostName: str = ..., port: int = ..., user: str = ..., password: str = ...): ...

    def __copy__(self): ...
    @staticmethod
    def applicationProxy() -> PySide2.QtNetwork.QNetworkProxy: ...
    def capabilities(self) -> PySide2.QtNetwork.QNetworkProxy.Capabilities: ...
    def hasRawHeader(self, headerName: PySide2.QtCore.QByteArray) -> bool: ...
    def header(self, header: PySide2.QtNetwork.QNetworkRequest.KnownHeaders) -> typing.Any: ...
    def hostName(self) -> str: ...
    def isCachingProxy(self) -> bool: ...
    def isTransparentProxy(self) -> bool: ...
    def password(self) -> str: ...
    def port(self) -> int: ...
    def rawHeader(self, headerName: PySide2.QtCore.QByteArray) -> PySide2.QtCore.QByteArray: ...
    def rawHeaderList(self) -> typing.List[PySide2.QtCore.QByteArray]: ...
    @staticmethod
    def setApplicationProxy(proxy: PySide2.QtNetwork.QNetworkProxy): ...
    def setCapabilities(self, capab: PySide2.QtNetwork.QNetworkProxy.Capabilities): ...
    def setHeader(self, header: PySide2.QtNetwork.QNetworkRequest.KnownHeaders, value: typing.Any): ...
    def setHostName(self, hostName: str): ...
    def setPassword(self, password: str): ...
    def setPort(self, port: int): ...
    def setRawHeader(self, headerName: PySide2.QtCore.QByteArray, value: PySide2.QtCore.QByteArray): ...
    def setType(self, type: PySide2.QtNetwork.QNetworkProxy.ProxyType): ...
    def setUser(self, userName: str): ...
    def swap(self, other: PySide2.QtNetwork.QNetworkProxy): ...
    def type(self) -> PySide2.QtNetwork.QNetworkProxy.ProxyType: ...
    def user(self) -> str: ...


class QNetworkProxyFactory(Shiboken.Object):

    def __init__(self): ...

    @staticmethod
    def proxyForQuery(query: PySide2.QtNetwork.QNetworkProxyQuery) -> typing.List[PySide2.QtNetwork.QNetworkProxy]: ...
    def queryProxy(self, query: PySide2.QtNetwork.QNetworkProxyQuery = ...) -> typing.List[PySide2.QtNetwork.QNetworkProxy]: ...
    @staticmethod
    def setApplicationProxyFactory(factory: PySide2.QtNetwork.QNetworkProxyFactory): ...
    @staticmethod
    def setUseSystemConfiguration(enable: bool): ...
    @staticmethod
    def systemProxyForQuery(query: PySide2.QtNetwork.QNetworkProxyQuery = ...) -> typing.List[PySide2.QtNetwork.QNetworkProxy]: ...
    @staticmethod
    def usesSystemConfiguration() -> bool: ...


class QNetworkProxyQuery(Shiboken.Object):

    class QueryType(object): ...
    TcpSocket                : QueryType = ... # 0x0
    UdpSocket                : QueryType = ... # 0x1
    SctpSocket               : QueryType = ... # 0x2
    TcpServer                : QueryType = ... # 0x64
    UrlRequest               : QueryType = ... # 0x65
    SctpServer               : QueryType = ... # 0x66

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, bindPort: int, protocolTag: str = ..., queryType: PySide2.QtNetwork.QNetworkProxyQuery.QueryType = ...): ...
    @typing.overload
    def __init__(self, hostname: str, port: int, protocolTag: str = ..., queryType: PySide2.QtNetwork.QNetworkProxyQuery.QueryType = ...): ...
    @typing.overload
    def __init__(self, networkConfiguration: PySide2.QtNetwork.QNetworkConfiguration, bindPort: int, protocolTag: str = ..., queryType: PySide2.QtNetwork.QNetworkProxyQuery.QueryType = ...): ...
    @typing.overload
    def __init__(self, networkConfiguration: PySide2.QtNetwork.QNetworkConfiguration, hostname: str, port: int, protocolTag: str = ..., queryType: PySide2.QtNetwork.QNetworkProxyQuery.QueryType = ...): ...
    @typing.overload
    def __init__(self, networkConfiguration: PySide2.QtNetwork.QNetworkConfiguration, requestUrl: PySide2.QtCore.QUrl, queryType: PySide2.QtNetwork.QNetworkProxyQuery.QueryType = ...): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QNetworkProxyQuery): ...
    @typing.overload
    def __init__(self, requestUrl: PySide2.QtCore.QUrl, queryType: PySide2.QtNetwork.QNetworkProxyQuery.QueryType = ...): ...

    def __copy__(self): ...
    def localPort(self) -> int: ...
    def networkConfiguration(self) -> PySide2.QtNetwork.QNetworkConfiguration: ...
    def peerHostName(self) -> str: ...
    def peerPort(self) -> int: ...
    def protocolTag(self) -> str: ...
    def queryType(self) -> PySide2.QtNetwork.QNetworkProxyQuery.QueryType: ...
    def setLocalPort(self, port: int): ...
    def setNetworkConfiguration(self, networkConfiguration: PySide2.QtNetwork.QNetworkConfiguration): ...
    def setPeerHostName(self, hostname: str): ...
    def setPeerPort(self, port: int): ...
    def setProtocolTag(self, protocolTag: str): ...
    def setQueryType(self, type: PySide2.QtNetwork.QNetworkProxyQuery.QueryType): ...
    def setUrl(self, url: PySide2.QtCore.QUrl): ...
    def swap(self, other: PySide2.QtNetwork.QNetworkProxyQuery): ...
    def url(self) -> PySide2.QtCore.QUrl: ...


class QNetworkReply(PySide2.QtCore.QIODevice):

    class NetworkError(object): ...
    NoError                  : NetworkError = ... # 0x0
    ConnectionRefusedError   : NetworkError = ... # 0x1
    RemoteHostClosedError    : NetworkError = ... # 0x2
    HostNotFoundError        : NetworkError = ... # 0x3
    TimeoutError             : NetworkError = ... # 0x4
    OperationCanceledError   : NetworkError = ... # 0x5
    SslHandshakeFailedError  : NetworkError = ... # 0x6
    TemporaryNetworkFailureError: NetworkError = ... # 0x7
    NetworkSessionFailedError: NetworkError = ... # 0x8
    BackgroundRequestNotAllowedError: NetworkError = ... # 0x9
    TooManyRedirectsError    : NetworkError = ... # 0xa
    InsecureRedirectError    : NetworkError = ... # 0xb
    UnknownNetworkError      : NetworkError = ... # 0x63
    ProxyConnectionRefusedError: NetworkError = ... # 0x65
    ProxyConnectionClosedError: NetworkError = ... # 0x66
    ProxyNotFoundError       : NetworkError = ... # 0x67
    ProxyTimeoutError        : NetworkError = ... # 0x68
    ProxyAuthenticationRequiredError: NetworkError = ... # 0x69
    UnknownProxyError        : NetworkError = ... # 0xc7
    ContentAccessDenied      : NetworkError = ... # 0xc9
    ContentOperationNotPermittedError: NetworkError = ... # 0xca
    ContentNotFoundError     : NetworkError = ... # 0xcb
    AuthenticationRequiredError: NetworkError = ... # 0xcc
    ContentReSendError       : NetworkError = ... # 0xcd
    ContentConflictError     : NetworkError = ... # 0xce
    ContentGoneError         : NetworkError = ... # 0xcf
    UnknownContentError      : NetworkError = ... # 0x12b
    ProtocolUnknownError     : NetworkError = ... # 0x12d
    ProtocolInvalidOperationError: NetworkError = ... # 0x12e
    ProtocolFailure          : NetworkError = ... # 0x18f
    InternalServerError      : NetworkError = ... # 0x191
    OperationNotImplementedError: NetworkError = ... # 0x192
    ServiceUnavailableError  : NetworkError = ... # 0x193
    UnknownServerError       : NetworkError = ... # 0x1f3

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def abort(self): ...
    def attribute(self, code: PySide2.QtNetwork.QNetworkRequest.Attribute) -> typing.Any: ...
    def close(self): ...
    def error(self) -> PySide2.QtNetwork.QNetworkReply.NetworkError: ...
    def hasRawHeader(self, headerName: PySide2.QtCore.QByteArray) -> bool: ...
    def header(self, header: PySide2.QtNetwork.QNetworkRequest.KnownHeaders) -> typing.Any: ...
    @typing.overload
    def ignoreSslErrors(self): ...
    @typing.overload
    def ignoreSslErrors(self, errors: typing.List[PySide2.QtNetwork.QSslError]): ...
    def ignoreSslErrorsImplementation(self, arg__1: typing.List[PySide2.QtNetwork.QSslError]): ...
    def isFinished(self) -> bool: ...
    def isRunning(self) -> bool: ...
    def isSequential(self) -> bool: ...
    def manager(self) -> PySide2.QtNetwork.QNetworkAccessManager: ...
    def operation(self) -> PySide2.QtNetwork.QNetworkAccessManager.Operation: ...
    def rawHeader(self, headerName: PySide2.QtCore.QByteArray) -> PySide2.QtCore.QByteArray: ...
    def rawHeaderList(self) -> typing.List[PySide2.QtCore.QByteArray]: ...
    def rawHeaderPairs(self) -> typing.List[typing.Tuple]: ...
    def readBufferSize(self) -> int: ...
    def request(self) -> PySide2.QtNetwork.QNetworkRequest: ...
    def setAttribute(self, code: PySide2.QtNetwork.QNetworkRequest.Attribute, value: typing.Any): ...
    def setError(self, errorCode: PySide2.QtNetwork.QNetworkReply.NetworkError, errorString: str): ...
    def setFinished(self, arg__1: bool): ...
    def setHeader(self, header: PySide2.QtNetwork.QNetworkRequest.KnownHeaders, value: typing.Any): ...
    def setOperation(self, operation: PySide2.QtNetwork.QNetworkAccessManager.Operation): ...
    def setRawHeader(self, headerName: PySide2.QtCore.QByteArray, value: PySide2.QtCore.QByteArray): ...
    def setReadBufferSize(self, size: int): ...
    def setRequest(self, request: PySide2.QtNetwork.QNetworkRequest): ...
    def setSslConfiguration(self, configuration: PySide2.QtNetwork.QSslConfiguration): ...
    def setSslConfigurationImplementation(self, arg__1: PySide2.QtNetwork.QSslConfiguration): ...
    def setUrl(self, url: PySide2.QtCore.QUrl): ...
    def sslConfiguration(self) -> PySide2.QtNetwork.QSslConfiguration: ...
    def sslConfigurationImplementation(self, arg__1: PySide2.QtNetwork.QSslConfiguration): ...
    def url(self) -> PySide2.QtCore.QUrl: ...
    def writeData(self, data: str, len: int) -> int: ...


class QNetworkRequest(Shiboken.Object):

    class Attribute(object): ...
    HttpStatusCodeAttribute  : Attribute = ... # 0x0
    HttpReasonPhraseAttribute: Attribute = ... # 0x1
    RedirectionTargetAttribute: Attribute = ... # 0x2
    ConnectionEncryptedAttribute: Attribute = ... # 0x3
    CacheLoadControlAttribute: Attribute = ... # 0x4
    CacheSaveControlAttribute: Attribute = ... # 0x5
    SourceIsFromCacheAttribute: Attribute = ... # 0x6
    DoNotBufferUploadDataAttribute: Attribute = ... # 0x7
    HttpPipeliningAllowedAttribute: Attribute = ... # 0x8
    HttpPipeliningWasUsedAttribute: Attribute = ... # 0x9
    CustomVerbAttribute      : Attribute = ... # 0xa
    CookieLoadControlAttribute: Attribute = ... # 0xb
    AuthenticationReuseAttribute: Attribute = ... # 0xc
    CookieSaveControlAttribute: Attribute = ... # 0xd
    MaximumDownloadBufferSizeAttribute: Attribute = ... # 0xe
    DownloadBufferAttribute  : Attribute = ... # 0xf
    SynchronousRequestAttribute: Attribute = ... # 0x10
    BackgroundRequestAttribute: Attribute = ... # 0x11
    SpdyAllowedAttribute     : Attribute = ... # 0x12
    SpdyWasUsedAttribute     : Attribute = ... # 0x13
    EmitAllUploadProgressSignalsAttribute: Attribute = ... # 0x14
    FollowRedirectsAttribute : Attribute = ... # 0x15
    HTTP2AllowedAttribute    : Attribute = ... # 0x16
    HTTP2WasUsedAttribute    : Attribute = ... # 0x17
    OriginalContentLengthAttribute: Attribute = ... # 0x18
    RedirectPolicyAttribute  : Attribute = ... # 0x19
    Http2DirectAttribute     : Attribute = ... # 0x1a
    ResourceTypeAttribute    : Attribute = ... # 0x1b
    User                     : Attribute = ... # 0x3e8
    UserMax                  : Attribute = ... # 0x7fff

    class CacheLoadControl(object): ...
    AlwaysNetwork            : CacheLoadControl = ... # 0x0
    PreferNetwork            : CacheLoadControl = ... # 0x1
    PreferCache              : CacheLoadControl = ... # 0x2
    AlwaysCache              : CacheLoadControl = ... # 0x3

    class KnownHeaders(object): ...
    ContentTypeHeader        : KnownHeaders = ... # 0x0
    ContentLengthHeader      : KnownHeaders = ... # 0x1
    LocationHeader           : KnownHeaders = ... # 0x2
    LastModifiedHeader       : KnownHeaders = ... # 0x3
    CookieHeader             : KnownHeaders = ... # 0x4
    SetCookieHeader          : KnownHeaders = ... # 0x5
    ContentDispositionHeader : KnownHeaders = ... # 0x6
    UserAgentHeader          : KnownHeaders = ... # 0x7
    ServerHeader             : KnownHeaders = ... # 0x8
    IfModifiedSinceHeader    : KnownHeaders = ... # 0x9
    ETagHeader               : KnownHeaders = ... # 0xa
    IfMatchHeader            : KnownHeaders = ... # 0xb
    IfNoneMatchHeader        : KnownHeaders = ... # 0xc

    class LoadControl(object): ...
    Automatic                : LoadControl = ... # 0x0
    Manual                   : LoadControl = ... # 0x1

    class Priority(object): ...
    HighPriority             : Priority = ... # 0x1
    NormalPriority           : Priority = ... # 0x3
    LowPriority              : Priority = ... # 0x5

    class RedirectPolicy(object): ...
    ManualRedirectPolicy     : RedirectPolicy = ... # 0x0
    NoLessSafeRedirectPolicy : RedirectPolicy = ... # 0x1
    SameOriginRedirectPolicy : RedirectPolicy = ... # 0x2
    UserVerifiedRedirectPolicy: RedirectPolicy = ... # 0x3

    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QNetworkRequest): ...
    @typing.overload
    def __init__(self, url: PySide2.QtCore.QUrl = ...): ...

    def __copy__(self): ...
    def attribute(self, code: PySide2.QtNetwork.QNetworkRequest.Attribute, defaultValue: typing.Any = ...) -> typing.Any: ...
    def hasRawHeader(self, headerName: PySide2.QtCore.QByteArray) -> bool: ...
    def header(self, header: PySide2.QtNetwork.QNetworkRequest.KnownHeaders) -> typing.Any: ...
    def maximumRedirectsAllowed(self) -> int: ...
    def originatingObject(self) -> PySide2.QtCore.QObject: ...
    def peerVerifyName(self) -> str: ...
    def priority(self) -> PySide2.QtNetwork.QNetworkRequest.Priority: ...
    def rawHeader(self, headerName: PySide2.QtCore.QByteArray) -> PySide2.QtCore.QByteArray: ...
    def rawHeaderList(self) -> typing.List[PySide2.QtCore.QByteArray]: ...
    def setAttribute(self, code: PySide2.QtNetwork.QNetworkRequest.Attribute, value: typing.Any): ...
    def setHeader(self, header: PySide2.QtNetwork.QNetworkRequest.KnownHeaders, value: typing.Any): ...
    def setMaximumRedirectsAllowed(self, maximumRedirectsAllowed: int): ...
    def setOriginatingObject(self, object: PySide2.QtCore.QObject): ...
    def setPeerVerifyName(self, peerName: str): ...
    def setPriority(self, priority: PySide2.QtNetwork.QNetworkRequest.Priority): ...
    def setRawHeader(self, headerName: PySide2.QtCore.QByteArray, value: PySide2.QtCore.QByteArray): ...
    def setSslConfiguration(self, configuration: PySide2.QtNetwork.QSslConfiguration): ...
    def setUrl(self, url: PySide2.QtCore.QUrl): ...
    def sslConfiguration(self) -> PySide2.QtNetwork.QSslConfiguration: ...
    def swap(self, other: PySide2.QtNetwork.QNetworkRequest): ...
    def url(self) -> PySide2.QtCore.QUrl: ...


class QNetworkSession(PySide2.QtCore.QObject):

    class SessionError(object): ...
    UnknownSessionError      : SessionError = ... # 0x0
    SessionAbortedError      : SessionError = ... # 0x1
    RoamingError             : SessionError = ... # 0x2
    OperationNotSupportedError: SessionError = ... # 0x3
    InvalidConfigurationError: SessionError = ... # 0x4

    class State(object): ...
    Invalid                  : State = ... # 0x0
    NotAvailable             : State = ... # 0x1
    Connecting               : State = ... # 0x2
    Connected                : State = ... # 0x3
    Closing                  : State = ... # 0x4
    Disconnected             : State = ... # 0x5
    Roaming                  : State = ... # 0x6

    class UsagePolicies(object): ...

    class UsagePolicy(object): ...
    NoPolicy                 : UsagePolicy = ... # 0x0
    NoBackgroundTrafficPolicy: UsagePolicy = ... # 0x1

    def __init__(self, connConfig: PySide2.QtNetwork.QNetworkConfiguration, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def accept(self): ...
    def activeTime(self) -> int: ...
    def bytesReceived(self) -> int: ...
    def bytesWritten(self) -> int: ...
    def close(self): ...
    def configuration(self) -> PySide2.QtNetwork.QNetworkConfiguration: ...
    def connectNotify(self, signal: PySide2.QtCore.QMetaMethod): ...
    def disconnectNotify(self, signal: PySide2.QtCore.QMetaMethod): ...
    def error(self) -> PySide2.QtNetwork.QNetworkSession.SessionError: ...
    def errorString(self) -> str: ...
    def ignore(self): ...
    def interface(self) -> PySide2.QtNetwork.QNetworkInterface: ...
    def isOpen(self) -> bool: ...
    def migrate(self): ...
    def open(self): ...
    def reject(self): ...
    def sessionProperty(self, key: str) -> typing.Any: ...
    def setSessionProperty(self, key: str, value: typing.Any): ...
    def state(self) -> PySide2.QtNetwork.QNetworkSession.State: ...
    def stop(self): ...
    def usagePolicies(self) -> PySide2.QtNetwork.QNetworkSession.UsagePolicies: ...
    def waitForOpened(self, msecs: int = ...) -> bool: ...


class QOcspCertificateStatus(object): ...


class QOcspResponse(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QOcspResponse): ...

    def __copy__(self): ...
    def certificateStatus(self) -> PySide2.QtNetwork.QOcspCertificateStatus: ...
    def revocationReason(self) -> PySide2.QtNetwork.QOcspRevocationReason: ...
    def subject(self) -> PySide2.QtNetwork.QSslCertificate: ...
    def swap(self, other: PySide2.QtNetwork.QOcspResponse): ...


class QOcspRevocationReason(object): ...


class QPasswordDigestor(Shiboken.Object):
    @staticmethod
    def deriveKeyPbkdf1(algorithm: PySide2.QtCore.QCryptographicHash.Algorithm, password: PySide2.QtCore.QByteArray, salt: PySide2.QtCore.QByteArray, iterations: int, dkLen: int) -> PySide2.QtCore.QByteArray: ...
    @staticmethod
    def deriveKeyPbkdf2(algorithm: PySide2.QtCore.QCryptographicHash.Algorithm, password: PySide2.QtCore.QByteArray, salt: PySide2.QtCore.QByteArray, iterations: int, dkLen: int) -> PySide2.QtCore.QByteArray: ...


class QSctpServer(PySide2.QtNetwork.QTcpServer):

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def incomingConnection(self, handle: int): ...
    def maximumChannelCount(self) -> int: ...
    def nextPendingDatagramConnection(self) -> PySide2.QtNetwork.QSctpSocket: ...
    def setMaximumChannelCount(self, count: int): ...


class QSctpSocket(PySide2.QtNetwork.QTcpSocket):

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def close(self): ...
    def disconnectFromHost(self): ...
    def isInDatagramMode(self) -> bool: ...
    def maximumChannelCount(self) -> int: ...
    def readData(self, data: str, maxlen: int) -> int: ...
    def readDatagram(self) -> PySide2.QtNetwork.QNetworkDatagram: ...
    def readLineData(self, data: str, maxlen: int) -> int: ...
    def setMaximumChannelCount(self, count: int): ...
    def writeDatagram(self, datagram: PySide2.QtNetwork.QNetworkDatagram) -> bool: ...


class QSsl(Shiboken.Object):

    class AlternativeNameEntryType(object): ...
    EmailEntry               : AlternativeNameEntryType = ... # 0x0
    DnsEntry                 : AlternativeNameEntryType = ... # 0x1
    IpAddressEntry           : AlternativeNameEntryType = ... # 0x2

    class EncodingFormat(object): ...
    Pem                      : EncodingFormat = ... # 0x0
    Der                      : EncodingFormat = ... # 0x1

    class KeyAlgorithm(object): ...
    Opaque                   : KeyAlgorithm = ... # 0x0
    Rsa                      : KeyAlgorithm = ... # 0x1
    Dsa                      : KeyAlgorithm = ... # 0x2
    Ec                       : KeyAlgorithm = ... # 0x3
    Dh                       : KeyAlgorithm = ... # 0x4

    class KeyType(object): ...
    PrivateKey               : KeyType = ... # 0x0
    PublicKey                : KeyType = ... # 0x1

    class SslOption(object): ...
    SslOptionDisableEmptyFragments: SslOption = ... # 0x1
    SslOptionDisableSessionTickets: SslOption = ... # 0x2
    SslOptionDisableCompression: SslOption = ... # 0x4
    SslOptionDisableServerNameIndication: SslOption = ... # 0x8
    SslOptionDisableLegacyRenegotiation: SslOption = ... # 0x10
    SslOptionDisableSessionSharing: SslOption = ... # 0x20
    SslOptionDisableSessionPersistence: SslOption = ... # 0x40
    SslOptionDisableServerCipherPreference: SslOption = ... # 0x80

    class SslOptions(object): ...

    class SslProtocol(object): ...
    SslV3                    : SslProtocol = ... # 0x0
    SslV2                    : SslProtocol = ... # 0x1
    TlsV1_0                  : SslProtocol = ... # 0x2
    TlsV1_1                  : SslProtocol = ... # 0x3
    TlsV1_2                  : SslProtocol = ... # 0x4
    AnyProtocol              : SslProtocol = ... # 0x5
    TlsV1SslV3               : SslProtocol = ... # 0x6
    SecureProtocols          : SslProtocol = ... # 0x7
    TlsV1_0OrLater           : SslProtocol = ... # 0x8
    TlsV1_1OrLater           : SslProtocol = ... # 0x9
    TlsV1_2OrLater           : SslProtocol = ... # 0xa
    DtlsV1_0                 : SslProtocol = ... # 0xb
    DtlsV1_0OrLater          : SslProtocol = ... # 0xc
    DtlsV1_2                 : SslProtocol = ... # 0xd
    DtlsV1_2OrLater          : SslProtocol = ... # 0xe
    TlsV1_3                  : SslProtocol = ... # 0xf
    TlsV1_3OrLater           : SslProtocol = ... # 0x10
    UnknownProtocol          : SslProtocol = ... # -0x1


class QSslCertificate(Shiboken.Object):

    class SubjectInfo(object): ...
    Organization             : SubjectInfo = ... # 0x0
    CommonName               : SubjectInfo = ... # 0x1
    LocalityName             : SubjectInfo = ... # 0x2
    OrganizationalUnitName   : SubjectInfo = ... # 0x3
    CountryName              : SubjectInfo = ... # 0x4
    StateOrProvinceName      : SubjectInfo = ... # 0x5
    DistinguishedNameQualifier: SubjectInfo = ... # 0x6
    SerialNumber             : SubjectInfo = ... # 0x7
    EmailAddress             : SubjectInfo = ... # 0x8

    @typing.overload
    def __init__(self, data: PySide2.QtCore.QByteArray = ..., format: PySide2.QtNetwork.QSsl.EncodingFormat = ...): ...
    @typing.overload
    def __init__(self, device: PySide2.QtCore.QIODevice, format: PySide2.QtNetwork.QSsl.EncodingFormat = ...): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QSslCertificate): ...

    def __copy__(self): ...
    def clear(self): ...
    def digest(self, algorithm: PySide2.QtCore.QCryptographicHash.Algorithm = ...) -> PySide2.QtCore.QByteArray: ...
    def effectiveDate(self) -> PySide2.QtCore.QDateTime: ...
    def expiryDate(self) -> PySide2.QtCore.QDateTime: ...
    def extensions(self) -> typing.List[PySide2.QtNetwork.QSslCertificateExtension]: ...
    @staticmethod
    def fromData(data: PySide2.QtCore.QByteArray, format: PySide2.QtNetwork.QSsl.EncodingFormat = ...) -> typing.List[PySide2.QtNetwork.QSslCertificate]: ...
    @staticmethod
    def fromDevice(device: PySide2.QtCore.QIODevice, format: PySide2.QtNetwork.QSsl.EncodingFormat = ...) -> typing.List[PySide2.QtNetwork.QSslCertificate]: ...
    @staticmethod
    def fromPath(path: str, format: PySide2.QtNetwork.QSsl.EncodingFormat = ..., syntax: PySide2.QtCore.QRegExp.PatternSyntax = ...) -> typing.List[PySide2.QtNetwork.QSslCertificate]: ...
    def handle(self) -> int: ...
    @staticmethod
    def importPkcs12(device: PySide2.QtCore.QIODevice, key: PySide2.QtNetwork.QSslKey, cert: PySide2.QtNetwork.QSslCertificate, caCertificates: typing.Optional[typing.List[PySide2.QtNetwork.QSslCertificate]] = ..., passPhrase: PySide2.QtCore.QByteArray = ...) -> bool: ...
    def isBlacklisted(self) -> bool: ...
    def isNull(self) -> bool: ...
    def isSelfSigned(self) -> bool: ...
    def issuerDisplayName(self) -> str: ...
    @typing.overload
    def issuerInfo(self, attribute: PySide2.QtCore.QByteArray) -> typing.List[str]: ...
    @typing.overload
    def issuerInfo(self, info: PySide2.QtNetwork.QSslCertificate.SubjectInfo) -> typing.List[str]: ...
    def issuerInfoAttributes(self) -> typing.List[PySide2.QtCore.QByteArray]: ...
    def publicKey(self) -> PySide2.QtNetwork.QSslKey: ...
    def serialNumber(self) -> PySide2.QtCore.QByteArray: ...
    def subjectAlternativeNames(self) -> typing.DefaultDict[str, typing.List[str]]: ...
    def subjectDisplayName(self) -> str: ...
    @typing.overload
    def subjectInfo(self, attribute: PySide2.QtCore.QByteArray) -> typing.List[str]: ...
    @typing.overload
    def subjectInfo(self, info: PySide2.QtNetwork.QSslCertificate.SubjectInfo) -> typing.List[str]: ...
    def subjectInfoAttributes(self) -> typing.List[PySide2.QtCore.QByteArray]: ...
    def swap(self, other: PySide2.QtNetwork.QSslCertificate): ...
    def toDer(self) -> PySide2.QtCore.QByteArray: ...
    def toPem(self) -> PySide2.QtCore.QByteArray: ...
    def toText(self) -> str: ...
    @staticmethod
    def verify(certificateChain: typing.List[PySide2.QtNetwork.QSslCertificate], hostName: str = ...) -> typing.List[PySide2.QtNetwork.QSslError]: ...
    def version(self) -> PySide2.QtCore.QByteArray: ...


class QSslCertificateExtension(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QSslCertificateExtension): ...

    def __copy__(self): ...
    def isCritical(self) -> bool: ...
    def isSupported(self) -> bool: ...
    def name(self) -> str: ...
    def oid(self) -> str: ...
    def swap(self, other: PySide2.QtNetwork.QSslCertificateExtension): ...
    def value(self) -> typing.Any: ...


class QSslCipher(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, name: str): ...
    @typing.overload
    def __init__(self, name: str, protocol: PySide2.QtNetwork.QSsl.SslProtocol): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QSslCipher): ...

    def __copy__(self): ...
    def authenticationMethod(self) -> str: ...
    def encryptionMethod(self) -> str: ...
    def isNull(self) -> bool: ...
    def keyExchangeMethod(self) -> str: ...
    def name(self) -> str: ...
    def protocol(self) -> PySide2.QtNetwork.QSsl.SslProtocol: ...
    def protocolString(self) -> str: ...
    def supportedBits(self) -> int: ...
    def swap(self, other: PySide2.QtNetwork.QSslCipher): ...
    def usedBits(self) -> int: ...


class QSslConfiguration(Shiboken.Object):

    class NextProtocolNegotiationStatus(object): ...
    NextProtocolNegotiationNone: NextProtocolNegotiationStatus = ... # 0x0
    NextProtocolNegotiationNegotiated: NextProtocolNegotiationStatus = ... # 0x1
    NextProtocolNegotiationUnsupported: NextProtocolNegotiationStatus = ... # 0x2

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QSslConfiguration): ...

    def __copy__(self): ...
    def allowedNextProtocols(self) -> typing.List[PySide2.QtCore.QByteArray]: ...
    def backendConfiguration(self) -> typing.Dict: ...
    def caCertificates(self) -> typing.List[PySide2.QtNetwork.QSslCertificate]: ...
    def ciphers(self) -> typing.List[PySide2.QtNetwork.QSslCipher]: ...
    @staticmethod
    def defaultConfiguration() -> PySide2.QtNetwork.QSslConfiguration: ...
    @staticmethod
    def defaultDtlsConfiguration() -> PySide2.QtNetwork.QSslConfiguration: ...
    def diffieHellmanParameters(self) -> PySide2.QtNetwork.QSslDiffieHellmanParameters: ...
    def dtlsCookieVerificationEnabled(self) -> bool: ...
    def ephemeralServerKey(self) -> PySide2.QtNetwork.QSslKey: ...
    def isNull(self) -> bool: ...
    def localCertificate(self) -> PySide2.QtNetwork.QSslCertificate: ...
    def localCertificateChain(self) -> typing.List[PySide2.QtNetwork.QSslCertificate]: ...
    def nextNegotiatedProtocol(self) -> PySide2.QtCore.QByteArray: ...
    def nextProtocolNegotiationStatus(self) -> PySide2.QtNetwork.QSslConfiguration.NextProtocolNegotiationStatus: ...
    def ocspStaplingEnabled(self) -> bool: ...
    def peerCertificate(self) -> PySide2.QtNetwork.QSslCertificate: ...
    def peerCertificateChain(self) -> typing.List[PySide2.QtNetwork.QSslCertificate]: ...
    def peerVerifyDepth(self) -> int: ...
    def peerVerifyMode(self) -> PySide2.QtNetwork.QSslSocket.PeerVerifyMode: ...
    def preSharedKeyIdentityHint(self) -> PySide2.QtCore.QByteArray: ...
    def privateKey(self) -> PySide2.QtNetwork.QSslKey: ...
    def protocol(self) -> PySide2.QtNetwork.QSsl.SslProtocol: ...
    def sessionCipher(self) -> PySide2.QtNetwork.QSslCipher: ...
    def sessionProtocol(self) -> PySide2.QtNetwork.QSsl.SslProtocol: ...
    def sessionTicket(self) -> PySide2.QtCore.QByteArray: ...
    def sessionTicketLifeTimeHint(self) -> int: ...
    def setAllowedNextProtocols(self, protocols: typing.List[PySide2.QtCore.QByteArray]): ...
    def setBackendConfiguration(self, backendConfiguration: typing.Dict = ...): ...
    def setBackendConfigurationOption(self, name: PySide2.QtCore.QByteArray, value: typing.Any): ...
    def setCaCertificates(self, certificates: typing.List[PySide2.QtNetwork.QSslCertificate]): ...
    def setCiphers(self, ciphers: typing.List[PySide2.QtNetwork.QSslCipher]): ...
    @staticmethod
    def setDefaultConfiguration(configuration: PySide2.QtNetwork.QSslConfiguration): ...
    @staticmethod
    def setDefaultDtlsConfiguration(configuration: PySide2.QtNetwork.QSslConfiguration): ...
    def setDiffieHellmanParameters(self, dhparams: PySide2.QtNetwork.QSslDiffieHellmanParameters): ...
    def setDtlsCookieVerificationEnabled(self, enable: bool): ...
    def setLocalCertificate(self, certificate: PySide2.QtNetwork.QSslCertificate): ...
    def setLocalCertificateChain(self, localChain: typing.List[PySide2.QtNetwork.QSslCertificate]): ...
    def setOcspStaplingEnabled(self, enable: bool): ...
    def setPeerVerifyDepth(self, depth: int): ...
    def setPeerVerifyMode(self, mode: PySide2.QtNetwork.QSslSocket.PeerVerifyMode): ...
    def setPreSharedKeyIdentityHint(self, hint: PySide2.QtCore.QByteArray): ...
    def setPrivateKey(self, key: PySide2.QtNetwork.QSslKey): ...
    def setProtocol(self, protocol: PySide2.QtNetwork.QSsl.SslProtocol): ...
    def setSessionTicket(self, sessionTicket: PySide2.QtCore.QByteArray): ...
    def setSslOption(self, option: PySide2.QtNetwork.QSsl.SslOption, on: bool): ...
    @staticmethod
    def supportedCiphers() -> typing.List[PySide2.QtNetwork.QSslCipher]: ...
    def swap(self, other: PySide2.QtNetwork.QSslConfiguration): ...
    @staticmethod
    def systemCaCertificates() -> typing.List[PySide2.QtNetwork.QSslCertificate]: ...
    def testSslOption(self, option: PySide2.QtNetwork.QSsl.SslOption) -> bool: ...


class QSslDiffieHellmanParameters(Shiboken.Object):

    class Error(object): ...
    NoError                  : Error = ... # 0x0
    InvalidInputDataError    : Error = ... # 0x1
    UnsafeParametersError    : Error = ... # 0x2

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QSslDiffieHellmanParameters): ...

    def __copy__(self): ...
    @staticmethod
    def defaultParameters() -> PySide2.QtNetwork.QSslDiffieHellmanParameters: ...
    def error(self) -> PySide2.QtNetwork.QSslDiffieHellmanParameters.Error: ...
    def errorString(self) -> str: ...
    @typing.overload
    @staticmethod
    def fromEncoded(device: PySide2.QtCore.QIODevice, format: PySide2.QtNetwork.QSsl.EncodingFormat = ...) -> PySide2.QtNetwork.QSslDiffieHellmanParameters: ...
    @typing.overload
    @staticmethod
    def fromEncoded(encoded: PySide2.QtCore.QByteArray, format: PySide2.QtNetwork.QSsl.EncodingFormat = ...) -> PySide2.QtNetwork.QSslDiffieHellmanParameters: ...
    def isEmpty(self) -> bool: ...
    def isValid(self) -> bool: ...
    def swap(self, other: PySide2.QtNetwork.QSslDiffieHellmanParameters): ...


class QSslError(Shiboken.Object):

    class SslError(object): ...
    NoError                  : SslError = ... # 0x0
    UnableToGetIssuerCertificate: SslError = ... # 0x1
    UnableToDecryptCertificateSignature: SslError = ... # 0x2
    UnableToDecodeIssuerPublicKey: SslError = ... # 0x3
    CertificateSignatureFailed: SslError = ... # 0x4
    CertificateNotYetValid   : SslError = ... # 0x5
    CertificateExpired       : SslError = ... # 0x6
    InvalidNotBeforeField    : SslError = ... # 0x7
    InvalidNotAfterField     : SslError = ... # 0x8
    SelfSignedCertificate    : SslError = ... # 0x9
    SelfSignedCertificateInChain: SslError = ... # 0xa
    UnableToGetLocalIssuerCertificate: SslError = ... # 0xb
    UnableToVerifyFirstCertificate: SslError = ... # 0xc
    CertificateRevoked       : SslError = ... # 0xd
    InvalidCaCertificate     : SslError = ... # 0xe
    PathLengthExceeded       : SslError = ... # 0xf
    InvalidPurpose           : SslError = ... # 0x10
    CertificateUntrusted     : SslError = ... # 0x11
    CertificateRejected      : SslError = ... # 0x12
    SubjectIssuerMismatch    : SslError = ... # 0x13
    AuthorityIssuerSerialNumberMismatch: SslError = ... # 0x14
    NoPeerCertificate        : SslError = ... # 0x15
    HostNameMismatch         : SslError = ... # 0x16
    NoSslSupport             : SslError = ... # 0x17
    CertificateBlacklisted   : SslError = ... # 0x18
    CertificateStatusUnknown : SslError = ... # 0x19
    OcspNoResponseFound      : SslError = ... # 0x1a
    OcspMalformedRequest     : SslError = ... # 0x1b
    OcspMalformedResponse    : SslError = ... # 0x1c
    OcspInternalError        : SslError = ... # 0x1d
    OcspTryLater             : SslError = ... # 0x1e
    OcspSigRequred           : SslError = ... # 0x1f
    OcspUnauthorized         : SslError = ... # 0x20
    OcspResponseCannotBeTrusted: SslError = ... # 0x21
    OcspResponseCertIdUnknown: SslError = ... # 0x22
    OcspResponseExpired      : SslError = ... # 0x23
    OcspStatusUnknown        : SslError = ... # 0x24
    UnspecifiedError         : SslError = ... # -0x1

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, error: PySide2.QtNetwork.QSslError.SslError): ...
    @typing.overload
    def __init__(self, error: PySide2.QtNetwork.QSslError.SslError, certificate: PySide2.QtNetwork.QSslCertificate): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QSslError): ...

    def __copy__(self): ...
    def certificate(self) -> PySide2.QtNetwork.QSslCertificate: ...
    def error(self) -> PySide2.QtNetwork.QSslError.SslError: ...
    def errorString(self) -> str: ...
    def swap(self, other: PySide2.QtNetwork.QSslError): ...


class QSslKey(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, device: PySide2.QtCore.QIODevice, algorithm: PySide2.QtNetwork.QSsl.KeyAlgorithm, format: PySide2.QtNetwork.QSsl.EncodingFormat = ..., type: PySide2.QtNetwork.QSsl.KeyType = ..., passPhrase: PySide2.QtCore.QByteArray = ...): ...
    @typing.overload
    def __init__(self, encoded: PySide2.QtCore.QByteArray, algorithm: PySide2.QtNetwork.QSsl.KeyAlgorithm, format: PySide2.QtNetwork.QSsl.EncodingFormat = ..., type: PySide2.QtNetwork.QSsl.KeyType = ..., passPhrase: PySide2.QtCore.QByteArray = ...): ...
    @typing.overload
    def __init__(self, handle: int, type: PySide2.QtNetwork.QSsl.KeyType = ...): ...
    @typing.overload
    def __init__(self, other: PySide2.QtNetwork.QSslKey): ...

    def __copy__(self): ...
    def algorithm(self) -> PySide2.QtNetwork.QSsl.KeyAlgorithm: ...
    def clear(self): ...
    def handle(self) -> int: ...
    def isNull(self) -> bool: ...
    def length(self) -> int: ...
    def swap(self, other: PySide2.QtNetwork.QSslKey): ...
    def toDer(self, passPhrase: PySide2.QtCore.QByteArray = ...) -> PySide2.QtCore.QByteArray: ...
    def toPem(self, passPhrase: PySide2.QtCore.QByteArray = ...) -> PySide2.QtCore.QByteArray: ...
    def type(self) -> PySide2.QtNetwork.QSsl.KeyType: ...


class QSslPreSharedKeyAuthenticator(Shiboken.Object):

    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, authenticator: PySide2.QtNetwork.QSslPreSharedKeyAuthenticator): ...

    def __copy__(self): ...
    def identity(self) -> PySide2.QtCore.QByteArray: ...
    def identityHint(self) -> PySide2.QtCore.QByteArray: ...
    def maximumIdentityLength(self) -> int: ...
    def maximumPreSharedKeyLength(self) -> int: ...
    def preSharedKey(self) -> PySide2.QtCore.QByteArray: ...
    def setIdentity(self, identity: PySide2.QtCore.QByteArray): ...
    def setPreSharedKey(self, preSharedKey: PySide2.QtCore.QByteArray): ...
    def swap(self, other: PySide2.QtNetwork.QSslPreSharedKeyAuthenticator): ...


class QSslSocket(PySide2.QtNetwork.QTcpSocket):

    class PeerVerifyMode(object): ...
    VerifyNone               : PeerVerifyMode = ... # 0x0
    QueryPeer                : PeerVerifyMode = ... # 0x1
    VerifyPeer               : PeerVerifyMode = ... # 0x2
    AutoVerifyPeer           : PeerVerifyMode = ... # 0x3

    class SslMode(object): ...
    UnencryptedMode          : SslMode = ... # 0x0
    SslClientMode            : SslMode = ... # 0x1
    SslServerMode            : SslMode = ... # 0x2

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def abort(self): ...
    def addCaCertificate(self, certificate: PySide2.QtNetwork.QSslCertificate): ...
    @typing.overload
    def addCaCertificates(self, certificates: typing.List[PySide2.QtNetwork.QSslCertificate]): ...
    @typing.overload
    def addCaCertificates(self, path: str, format: PySide2.QtNetwork.QSsl.EncodingFormat = ..., syntax: PySide2.QtCore.QRegExp.PatternSyntax = ...) -> bool: ...
    @staticmethod
    def addDefaultCaCertificate(certificate: PySide2.QtNetwork.QSslCertificate): ...
    @typing.overload
    @staticmethod
    def addDefaultCaCertificates(certificates: typing.List[PySide2.QtNetwork.QSslCertificate]): ...
    @typing.overload
    @staticmethod
    def addDefaultCaCertificates(path: str, format: PySide2.QtNetwork.QSsl.EncodingFormat = ..., syntax: PySide2.QtCore.QRegExp.PatternSyntax = ...) -> bool: ...
    def atEnd(self) -> bool: ...
    def bytesAvailable(self) -> int: ...
    def bytesToWrite(self) -> int: ...
    def caCertificates(self) -> typing.List[PySide2.QtNetwork.QSslCertificate]: ...
    def canReadLine(self) -> bool: ...
    def ciphers(self) -> typing.List[PySide2.QtNetwork.QSslCipher]: ...
    def close(self): ...
    @typing.overload
    def connectToHost(self, address: PySide2.QtNetwork.QHostAddress, port: int, mode: PySide2.QtCore.QIODevice.OpenMode = ...): ...
    @typing.overload
    def connectToHost(self, hostName: str, port: int, openMode: PySide2.QtCore.QIODevice.OpenMode = ..., protocol: PySide2.QtNetwork.QAbstractSocket.NetworkLayerProtocol = ...): ...
    @typing.overload
    def connectToHostEncrypted(self, hostName: str, port: int, mode: PySide2.QtCore.QIODevice.OpenMode = ..., protocol: PySide2.QtNetwork.QAbstractSocket.NetworkLayerProtocol = ...): ...
    @typing.overload
    def connectToHostEncrypted(self, hostName: str, port: int, sslPeerName: str, mode: PySide2.QtCore.QIODevice.OpenMode = ..., protocol: PySide2.QtNetwork.QAbstractSocket.NetworkLayerProtocol = ...): ...
    @staticmethod
    def defaultCaCertificates() -> typing.List[PySide2.QtNetwork.QSslCertificate]: ...
    @staticmethod
    def defaultCiphers() -> typing.List[PySide2.QtNetwork.QSslCipher]: ...
    def disconnectFromHost(self): ...
    def encryptedBytesAvailable(self) -> int: ...
    def encryptedBytesToWrite(self) -> int: ...
    def flush(self) -> bool: ...
    @typing.overload
    def ignoreSslErrors(self): ...
    @typing.overload
    def ignoreSslErrors(self, errors: typing.List[PySide2.QtNetwork.QSslError]): ...
    def isEncrypted(self) -> bool: ...
    def localCertificate(self) -> PySide2.QtNetwork.QSslCertificate: ...
    def localCertificateChain(self) -> typing.List[PySide2.QtNetwork.QSslCertificate]: ...
    def mode(self) -> PySide2.QtNetwork.QSslSocket.SslMode: ...
    def ocspResponses(self) -> typing.List[PySide2.QtNetwork.QOcspResponse]: ...
    def peerCertificate(self) -> PySide2.QtNetwork.QSslCertificate: ...
    def peerCertificateChain(self) -> typing.List[PySide2.QtNetwork.QSslCertificate]: ...
    def peerVerifyDepth(self) -> int: ...
    def peerVerifyMode(self) -> PySide2.QtNetwork.QSslSocket.PeerVerifyMode: ...
    def peerVerifyName(self) -> str: ...
    def privateKey(self) -> PySide2.QtNetwork.QSslKey: ...
    def protocol(self) -> PySide2.QtNetwork.QSsl.SslProtocol: ...
    def readData(self, data: str, maxlen: int) -> int: ...
    def resume(self): ...
    def sessionCipher(self) -> PySide2.QtNetwork.QSslCipher: ...
    def sessionProtocol(self) -> PySide2.QtNetwork.QSsl.SslProtocol: ...
    def setCaCertificates(self, certificates: typing.List[PySide2.QtNetwork.QSslCertificate]): ...
    @typing.overload
    def setCiphers(self, ciphers: typing.List[PySide2.QtNetwork.QSslCipher]): ...
    @typing.overload
    def setCiphers(self, ciphers: str): ...
    @staticmethod
    def setDefaultCaCertificates(certificates: typing.List[PySide2.QtNetwork.QSslCertificate]): ...
    @staticmethod
    def setDefaultCiphers(ciphers: typing.List[PySide2.QtNetwork.QSslCipher]): ...
    @typing.overload
    def setLocalCertificate(self, certificate: PySide2.QtNetwork.QSslCertificate): ...
    @typing.overload
    def setLocalCertificate(self, fileName: str, format: PySide2.QtNetwork.QSsl.EncodingFormat = ...): ...
    def setLocalCertificateChain(self, localChain: typing.List[PySide2.QtNetwork.QSslCertificate]): ...
    def setPeerVerifyDepth(self, depth: int): ...
    def setPeerVerifyMode(self, mode: PySide2.QtNetwork.QSslSocket.PeerVerifyMode): ...
    def setPeerVerifyName(self, hostName: str): ...
    @typing.overload
    def setPrivateKey(self, fileName: str, algorithm: PySide2.QtNetwork.QSsl.KeyAlgorithm = ..., format: PySide2.QtNetwork.QSsl.EncodingFormat = ..., passPhrase: PySide2.QtCore.QByteArray = ...): ...
    @typing.overload
    def setPrivateKey(self, key: PySide2.QtNetwork.QSslKey): ...
    def setProtocol(self, protocol: PySide2.QtNetwork.QSsl.SslProtocol): ...
    def setReadBufferSize(self, size: int): ...
    def setSocketDescriptor(self, socketDescriptor: int, state: PySide2.QtNetwork.QAbstractSocket.SocketState = ..., openMode: PySide2.QtCore.QIODevice.OpenMode = ...) -> bool: ...
    def setSocketOption(self, option: PySide2.QtNetwork.QAbstractSocket.SocketOption, value: typing.Any): ...
    def setSslConfiguration(self, config: PySide2.QtNetwork.QSslConfiguration): ...
    def socketOption(self, option: PySide2.QtNetwork.QAbstractSocket.SocketOption) -> typing.Any: ...
    def sslConfiguration(self) -> PySide2.QtNetwork.QSslConfiguration: ...
    def sslErrors(self) -> typing.List[PySide2.QtNetwork.QSslError]: ...
    @staticmethod
    def sslLibraryBuildVersionNumber() -> int: ...
    @staticmethod
    def sslLibraryBuildVersionString() -> str: ...
    @staticmethod
    def sslLibraryVersionNumber() -> int: ...
    @staticmethod
    def sslLibraryVersionString() -> str: ...
    def startClientEncryption(self): ...
    def startServerEncryption(self): ...
    @staticmethod
    def supportedCiphers() -> typing.List[PySide2.QtNetwork.QSslCipher]: ...
    @staticmethod
    def supportsSsl() -> bool: ...
    @staticmethod
    def systemCaCertificates() -> typing.List[PySide2.QtNetwork.QSslCertificate]: ...
    def waitForBytesWritten(self, msecs: int = ...) -> bool: ...
    def waitForConnected(self, msecs: int = ...) -> bool: ...
    def waitForDisconnected(self, msecs: int = ...) -> bool: ...
    def waitForEncrypted(self, msecs: int = ...) -> bool: ...
    def waitForReadyRead(self, msecs: int = ...) -> bool: ...
    def writeData(self, data: str, len: int) -> int: ...


class QTcpServer(PySide2.QtCore.QObject):

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def addPendingConnection(self, socket: PySide2.QtNetwork.QTcpSocket): ...
    def close(self): ...
    def errorString(self) -> str: ...
    def hasPendingConnections(self) -> bool: ...
    def incomingConnection(self, handle: int): ...
    def isListening(self) -> bool: ...
    def listen(self, address: PySide2.QtNetwork.QHostAddress = ..., port: int = ...) -> bool: ...
    def maxPendingConnections(self) -> int: ...
    def nextPendingConnection(self) -> PySide2.QtNetwork.QTcpSocket: ...
    def pauseAccepting(self): ...
    def proxy(self) -> PySide2.QtNetwork.QNetworkProxy: ...
    def resumeAccepting(self): ...
    def serverAddress(self) -> PySide2.QtNetwork.QHostAddress: ...
    def serverError(self) -> PySide2.QtNetwork.QAbstractSocket.SocketError: ...
    def serverPort(self) -> int: ...
    def setMaxPendingConnections(self, numConnections: int): ...
    def setProxy(self, networkProxy: PySide2.QtNetwork.QNetworkProxy): ...
    def setSocketDescriptor(self, socketDescriptor: int) -> bool: ...
    def socketDescriptor(self) -> int: ...
    def waitForNewConnection(self, msec: int, timedOut: bool) -> bool: ...


class QTcpSocket(PySide2.QtNetwork.QAbstractSocket):

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...


class QUdpSocket(PySide2.QtNetwork.QAbstractSocket):

    def __init__(self, parent: typing.Optional[PySide2.QtCore.QObject] = ...): ...

    def hasPendingDatagrams(self) -> bool: ...
    @typing.overload
    def joinMulticastGroup(self, groupAddress: PySide2.QtNetwork.QHostAddress) -> bool: ...
    @typing.overload
    def joinMulticastGroup(self, groupAddress: PySide2.QtNetwork.QHostAddress, iface: PySide2.QtNetwork.QNetworkInterface) -> bool: ...
    @typing.overload
    def leaveMulticastGroup(self, groupAddress: PySide2.QtNetwork.QHostAddress) -> bool: ...
    @typing.overload
    def leaveMulticastGroup(self, groupAddress: PySide2.QtNetwork.QHostAddress, iface: PySide2.QtNetwork.QNetworkInterface) -> bool: ...
    def multicastInterface(self) -> PySide2.QtNetwork.QNetworkInterface: ...
    def pendingDatagramSize(self) -> int: ...
    def readDatagram(self, data: str, maxlen: int, host: PySide2.QtNetwork.QHostAddress, port: int) -> int: ...
    def receiveDatagram(self, maxSize: int = ...) -> PySide2.QtNetwork.QNetworkDatagram: ...
    def setMulticastInterface(self, iface: PySide2.QtNetwork.QNetworkInterface): ...
    @typing.overload
    def writeDatagram(self, datagram: PySide2.QtCore.QByteArray, host: PySide2.QtNetwork.QHostAddress, port: int) -> int: ...
    @typing.overload
    def writeDatagram(self, datagram: PySide2.QtNetwork.QNetworkDatagram) -> int: ...

# eof
